@@ -16,7 +16,6 @@ from aminer.analysis.MatchFilter import MatchFilter
 from aminer.analysis.MatchValueAverageChangeDetector import MatchValueAverageChangeDetector
 from aminer.analysis.MatchValueStreamWriter import MatchValueStreamWriter
 from aminer.analysis.TimeCorrelationViolationDetector import TimeCorrelationViolationDetector
-from aminer.analysis.TimestampCorrectionFilters import SimpleMonotonicTimestampAdjust
 from aminer.analysis.TimestampsUnsortedDetector import TimestampsUnsortedDetector
 from aminer.analysis.AllowlistViolationDetector import AllowlistViolationDetector
 from aminer.events.StreamPrinterEventHandler import StreamPrinterEventHandler
@@ -25,6 +24,7 @@ from aminer.events.DefaultMailNotificationEventHandler import DefaultMailNotific
 from aminer.events.JsonConverterHandler import JsonConverterHandler
 from aminer.input.SimpleByteStreamLineAtomizerFactory import SimpleByteStreamLineAtomizerFactory
 from aminer.input.SimpleMultisourceAtomSync import SimpleMultisourceAtomSync
+from aminer.parsing.AnyByteDataModelElement import AnyByteDataModelElement
 from aminer.parsing.FirstMatchModelElement import FirstMatchModelElement
 from aminer.parsing.SequenceModelElement import SequenceModelElement
 from aminer.parsing.VariableByteDataModelElement import VariableByteDataModelElement
@@ -32,6 +32,7 @@ from aminer.parsing.FixedDataModelElement import FixedDataModelElement
 from aminer.parsing.DateTimeModelElement import DateTimeModelElement
 from aminer.parsing.FixedWordlistDataModelElement import FixedWordlistDataModelElement
 from aminer.parsing.DecimalIntegerValueModelElement import DecimalIntegerValueModelElement
+from aminer.parsing.DecimalFloatValueModelElement import DecimalFloatValueModelElement
 from aminer.parsing.RepeatedElementDataModelElement import RepeatedElementDataModelElement
 from aminer.parsing.OptionalMatchModelElement import OptionalMatchModelElement
 from aminer.parsing.ElementValueBranchModelElement import ElementValueBranchModelElement
@@ -113,7 +114,7 @@ class YamlConfigTest(TestBase):
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[0], StreamPrinterEventHandler))
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[1], SyslogWriterEventHandler))
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[2], DefaultMailNotificationEventHandler))
-        self.assertEqual(context.atomizer_factory.default_timestamp_paths, ['/accesslog/time'])
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, ['/accesslog/time'])
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model, SequenceModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[0], VariableByteDataModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[1], FixedDataModelElement))
@@ -254,7 +255,7 @@ class YamlConfigTest(TestBase):
         self.assertTrue(isinstance(context.registered_components[1][0], NewMatchPathDetector))
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[0], JsonConverterHandler))
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[0].json_event_handlers[0], StreamPrinterEventHandler))
-        self.assertEqual(context.atomizer_factory.default_timestamp_paths, ['/accesslog/time'])
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, ['/accesslog/time'])
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model, SequenceModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[0], VariableByteDataModelElement))
 
@@ -271,16 +272,16 @@ class YamlConfigTest(TestBase):
         self.assertTrue(isinstance(context.registered_components[2][0], NewMatchPathValueDetector))
         self.assertTrue(isinstance(context.registered_components[3][0], NewMatchPathValueComboDetector))
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[0], StreamPrinterEventHandler))
-        self.assertEqual(context.atomizer_factory.default_timestamp_paths, ['/accesslog/time'])
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, ['/accesslog/time'])
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model, SequenceModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[0], VariableByteDataModelElement))
 
         # specific learn_mode arguments should be preferred.
         context = AnalysisContext(aminer_config)
         context.build_analysis_pipeline()
-        self.assertTrue(context.registered_components[1][0].auto_include_flag)
-        self.assertTrue(context.registered_components[2][0].auto_include_flag)
-        self.assertFalse(context.registered_components[3][0].auto_include_flag)
+        self.assertTrue(context.registered_components[1][0].learn_mode)
+        self.assertTrue(context.registered_components[2][0].learn_mode)
+        self.assertFalse(context.registered_components[3][0].learn_mode)
 
         # unset specific learn_mode parameters and set LearnMode True.
         for component in aminer_config.yaml_data['Analysis']:
@@ -288,16 +289,16 @@ class YamlConfigTest(TestBase):
         context = AnalysisContext(aminer_config)
         context.build_analysis_pipeline()
         for key in context.registered_components:
-            if hasattr(context.registered_components[key][0], 'auto_include_flag'):
-                self.assertTrue(context.registered_components[key][0].auto_include_flag)
+            if hasattr(context.registered_components[key][0], 'learn_mode'):
+                self.assertTrue(context.registered_components[key][0].learn_mode)
 
         # unset specific learn_mode parameters and set LearnMode False.
         aminer_config.yaml_data['LearnMode'] = False
         context = AnalysisContext(aminer_config)
         context.build_analysis_pipeline()
         for key in context.registered_components:
-            if hasattr(context.registered_components[key][0], 'auto_include_flag'):
-                self.assertFalse(context.registered_components[key][0].auto_include_flag)
+            if hasattr(context.registered_components[key][0], 'learn_mode'):
+                self.assertFalse(context.registered_components[key][0].learn_mode)
 
         # unset LearnMode config property. An Error should be raised.
         del aminer_config.yaml_data['LearnMode']
@@ -317,14 +318,14 @@ class YamlConfigTest(TestBase):
         self.assertTrue(isinstance(context.registered_components[2][0], NewMatchPathValueDetector))
         self.assertTrue(isinstance(context.registered_components[3][0], NewMatchPathValueComboDetector))
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[0], StreamPrinterEventHandler))
-        self.assertEqual(context.atomizer_factory.default_timestamp_paths, ['/model/accesslog/time'])
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, ['/model/accesslog/time'])
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model, SequenceModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[0], VariableByteDataModelElement))
 
         # test with MultiSource: True. Expects a SimpleByteStreamLineAtomizerFactory with a SimpleMultisourceAtomSync.
         self.assertTrue(isinstance(context.atomizer_factory, SimpleByteStreamLineAtomizerFactory))
         self.assertTrue(isinstance(context.atomizer_factory.atom_handler_list[0], SimpleMultisourceAtomSync))
-        self.assertEqual(context.atomizer_factory.default_timestamp_paths, [aminer_config.yaml_data['Input']['timestamp_paths']])
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, [aminer_config.yaml_data['Input']['timestamp_paths']])
 
         # test with MultiSource: False. Expects a SimpleByteStreamLineAtomizerFactory with a AtomFilters.SubhandlerFilter.
         aminer_config.yaml_data['Input']['multi_source'] = False
@@ -332,7 +333,7 @@ class YamlConfigTest(TestBase):
         context.build_analysis_pipeline()
         self.assertTrue(isinstance(context.atomizer_factory, SimpleByteStreamLineAtomizerFactory))
         self.assertTrue(isinstance(context.atomizer_factory.atom_handler_list[0], SubhandlerFilter))
-        self.assertEqual(context.atomizer_factory.default_timestamp_paths, [aminer_config.yaml_data['Input']['timestamp_paths']])
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, [aminer_config.yaml_data['Input']['timestamp_paths']])
 
     def test16_parsermodeltype_parameter_for_another_parsermodel_type(self):
         """This test checks if all ModelElements with child elements are working properly."""
@@ -347,7 +348,7 @@ class YamlConfigTest(TestBase):
         self.assertTrue(isinstance(context.registered_components[2][0], NewMatchPathValueDetector))
         self.assertTrue(isinstance(context.registered_components[3][0], NewMatchPathValueComboDetector))
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[0], StreamPrinterEventHandler))
-        self.assertEqual(context.atomizer_factory.default_timestamp_paths, ['/model/accesslog/time'])
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, ['/model/accesslog/time'])
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model, FirstMatchModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[0], SequenceModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[0].children[0], FixedDataModelElement))
@@ -450,7 +451,7 @@ class YamlConfigTest(TestBase):
             self.assertEqual(type(yml_registered_components_by_name[name]), type(py_registered_components_by_name[name]))
         self.assertEqual(len(yml_context.real_time_triggered_components), len(py_context.real_time_triggered_components))
         # the atom_handler_list is not equal as the python version uses a SimpleMonotonicTimestampAdjust.
-        self.assertEqual(yml_context.atomizer_factory.default_timestamp_paths, py_context.atomizer_factory.default_timestamp_paths)
+        self.assertEqual(yml_context.atomizer_factory.default_timestamp_path_list, py_context.atomizer_factory.default_timestamp_path_list)
         self.assertEqual(type(yml_context.atomizer_factory.event_handler_list), type(py_context.atomizer_factory.event_handler_list))
 
     def test18_etd_order(self):
@@ -507,11 +508,10 @@ class YamlConfigTest(TestBase):
         context = AnalysisContext(aminer_config)
         context.build_analysis_pipeline()
 
-        print(context.registered_components)
         context.aminer_config.yaml_data['Analysis'][2]['suppress'] = False
         context.atomizer_factory.event_handler_list[0].stream = self.output_stream
         default_nmpd = context.registered_components[3][0]
-        default_nmpd.output_log_line = False
+        default_nmpd.output_logline = False
         self.assertTrue(default_nmpd.receive_atom(log_atom_fixed_dme))
         self.assertEqual(self.output_stream.getvalue(), __expected_string1 % (
             datetime.fromtimestamp(t).strftime(datetime_format_string), default_nmpd.__class__.__name__, 'DefaultNewMatchPathDetector', 1,
@@ -523,12 +523,12 @@ class YamlConfigTest(TestBase):
         context.build_analysis_pipeline()
         context.atomizer_factory.event_handler_list[0].stream = self.output_stream
         default_nmpd = context.registered_components[3][0]
-        default_nmpd.output_log_line = False
+        default_nmpd.output_logline = False
         self.assertTrue(default_nmpd.receive_atom(log_atom_fixed_dme))
         self.assertEqual(self.output_stream.getvalue(), "")
         self.reset_output_stream()
 
-        value_combo_det = context.registered_components[2][0]
+        value_combo_det = context.registered_components[1][0]
         log_atom_sequence_me = LogAtom(match_element_sequence_me.get_match_string(), ParserMatch(match_element_sequence_me), t,
                                        value_combo_det)
         context.atomizer_factory.event_handler_list[0].stream = self.output_stream
@@ -538,10 +538,10 @@ class YamlConfigTest(TestBase):
             'ValueComboDetector', 1, string2))
         self.reset_output_stream()
 
-        context.aminer_config.yaml_data['Analysis'][1]['suppress'] = True
+        context.aminer_config.yaml_data['Analysis'][0]['suppress'] = True
         context = AnalysisContext(aminer_config)
         context.build_analysis_pipeline()
-        value_combo_det = context.registered_components[2][0]
+        value_combo_det = context.registered_components[1][0]
         context.atomizer_factory.event_handler_list[0].stream = self.output_stream
         self.assertTrue(value_combo_det.receive_atom(log_atom_sequence_me))
         self.assertEqual(self.output_stream.getvalue(), "")
@@ -596,7 +596,7 @@ class YamlConfigTest(TestBase):
         spec.loader.exec_module(aminer_config)
         self.assertRaises(ValueError, aminer_config.load_yaml, 'unit/data/configfiles/wrong_email.yml')
 
-        with open('/usr/lib/logdata-anomaly-miner/aminer/schemas/BaseSchema.yml', 'r') as sma:
+        with open('/usr/lib/logdata-anomaly-miner/aminer/schemas/BaseSchema.py', 'r') as sma:
             # skipcq: PYL-W0123
             base_schema = eval(sma.read())
         self.assertEqual(base_schema['MailAlerting.TargetAddress']['regex'], base_schema['MailAlerting.FromAddress']['regex'])
@@ -619,12 +619,13 @@ class YamlConfigTest(TestBase):
             aminer_config.load_yaml('unit/data/configfiles/filter_config_errors.yml')
         except ValueError as e:
             msg = "Config-Error: {'AMinerGroup': ['unknown field'], 'Analysis': [{0: ['none or more than one rule validate', {'oneof " \
-                  "definition 25': [{'learn_mode': ['unknown field'], 'reset_after_report_flag': ['unknown field'], 'type': {'allowed': [" \
-                  "'ParserCount']}}]}]}], 'EventHandlers': [{1: ['none or more than one rule validate', {'oneof definition 3': [{" \
+                  "definition 27': [{'learn_mode': ['unknown field'], 'reset_after_report_flag': ['unknown field'], 'type': {'allowed': [" \
+                  "'ParserCount']}}]}]}], 'EventHandlers': [{1: ['none or more than one rule validate', {'oneof definition 4': [{" \
                   "'output_file_path': ['unknown field'], 'type': {'allowed': ['SyslogWriterEventHandler']}}]}]}], 'Parser': [{0: ['none " \
                   "or more than one rule validate', {'oneof definition 0': [{'args2': ['unknown field'], 'type': {'forbidden': [" \
                   "'ElementValueBranchModelElement', 'DecimalIntegerValueModelElement', 'DecimalFloatValueModelElement', " \
-                  "'DateTimeModelElement', 'MultiLocaleDateTimeModelElement', 'DelimitedDataModelElement', 'JsonModelElement']}}]}]}]}"
+                  "'DateTimeModelElement', 'MultiLocaleDateTimeModelElement', 'DelimitedDataModelElement', 'JsonModelElement', " \
+                  "'JsonStringModelElement']}}]}]}]}"
             self.assertEqual(msg, str(e))
         self.assertRaises(ValueError, aminer_config.load_yaml, 'unit/data/configfiles/filter_config_errors.yml')
 
@@ -673,12 +674,66 @@ class YamlConfigTest(TestBase):
         context = AnalysisContext(aminer_config)
         self.assertRaises(ValueError, context.build_analysis_pipeline)
 
+    def test30_parser_model_files(self):
+        """Test if parser models from conf-enabled work properly."""
+        spec = importlib.util.spec_from_file_location('aminer_config', '/usr/lib/logdata-anomaly-miner/aminer/YamlConfig.py')
+        aminer_config = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(aminer_config)
+        aminer_config.load_yaml('unit/data/configfiles/main.yml')
+        context = AnalysisContext(aminer_config)
+        context.build_analysis_pipeline()
+        pm = context.atomizer_factory.parsing_model
+        self.assertTrue(isinstance(context.registered_components[0][0], SubhandlerFilter))
+        self.assertTrue(isinstance(context.registered_components[1][0], NewMatchPathDetector))
+        self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[0], StreamPrinterEventHandler))
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, [""])
+        self.assertTrue(isinstance(pm, FirstMatchModelElement))
+
+        # Sub1
+        self.assertTrue(isinstance(pm.children[0], SequenceModelElement))
+        self.assertTrue(isinstance(pm.children[0].children[0], FixedDataModelElement))
+        self.assertEqual(pm.children[0].children[0].element_id, "fix1")
+        self.assertTrue(isinstance(pm.children[0].children[1], DecimalIntegerValueModelElement))
+        self.assertEqual(pm.children[0].children[1].element_id, "decimal1")
+
+        # Sub2
+        self.assertTrue(isinstance(pm.children[1], SequenceModelElement))
+        self.assertTrue(isinstance(pm.children[1].children[0], DecimalIntegerValueModelElement))
+        self.assertEqual(pm.children[1].children[0].element_id, "decimal2")
+        self.assertTrue(isinstance(pm.children[1].children[1], FixedDataModelElement))
+        self.assertEqual(pm.children[1].children[1].element_id, "fix2")
+        self.assertTrue(isinstance(pm.children[1].children[2], DecimalFloatValueModelElement))
+        self.assertEqual(pm.children[1].children[2].element_id, "decimalFloat2")
+
+        # Sub2 - Sub3
+        self.assertTrue(isinstance(pm.children[1].children[3], FirstMatchModelElement))
+        self.assertTrue(isinstance(pm.children[1].children[3].children[0], SequenceModelElement))
+        self.assertTrue(isinstance(pm.children[1].children[3].children[0].children[0], FixedDataModelElement))
+        self.assertEqual(pm.children[1].children[3].children[0].children[0].element_id, "fix3")
+        self.assertTrue(isinstance(pm.children[1].children[3].children[0].children[1], DecimalFloatValueModelElement))
+        self.assertEqual(pm.children[1].children[3].children[0].children[1].element_id, "decimalFloat3")
+        self.assertTrue(isinstance(pm.children[1].children[3].children[1], AnyByteDataModelElement))
+        self.assertEqual(pm.children[1].children[3].children[1].element_id, "any3")
+
+        # Sub3
+        self.assertTrue(isinstance(pm.children[2], FirstMatchModelElement))
+        self.assertTrue(isinstance(pm.children[2].children[0], SequenceModelElement))
+        self.assertTrue(isinstance(pm.children[2].children[0].children[0], FixedDataModelElement))
+        self.assertEqual(pm.children[2].children[0].children[0].element_id, "fix3")
+        self.assertTrue(isinstance(pm.children[2].children[0].children[1], DecimalFloatValueModelElement))
+        self.assertEqual(pm.children[2].children[0].children[1].element_id, "decimalFloat3")
+        self.assertTrue(isinstance(pm.children[2].children[1], AnyByteDataModelElement))
+        self.assertEqual(pm.children[2].children[1].element_id, "any3")
+
+        # ApacheAccessModel
+        self.assertEqual(pm.children[3].element_id, "accesslog")
+
     def run_empty_components_tests(self, context):
         """Run the empty components tests."""
         self.assertTrue(isinstance(context.registered_components[0][0], SubhandlerFilter))
         self.assertTrue(isinstance(context.registered_components[1][0], NewMatchPathDetector))
         self.assertTrue(isinstance(context.atomizer_factory.event_handler_list[0], StreamPrinterEventHandler))
-        self.assertEqual(context.atomizer_factory.default_timestamp_paths, ['/accesslog/time'])
+        self.assertEqual(context.atomizer_factory.default_timestamp_path_list, ['/accesslog/time'])
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model, SequenceModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[0], VariableByteDataModelElement))
         self.assertTrue(isinstance(context.atomizer_factory.parsing_model.children[1], FixedDataModelElement))
