@@ -1,5 +1,4 @@
 import time
-from datetime import datetime
 from kafka import KafkaConsumer
 from aminer.events.JsonConverterHandler import JsonConverterHandler
 from aminer.events.KafkaEventHandler import KafkaEventHandler
@@ -13,7 +12,7 @@ from unit.TestBase import TestBase
 class KafkaEventHandlerTest(TestBase):
     """Unittests for the KafkaEventHandler."""
 
-    output_log_line = True
+    output_logline = True
     kafka_topic = 'test_topic'
     kafka_group = 'test_group'
     consumer = None
@@ -32,7 +31,7 @@ class KafkaEventHandlerTest(TestBase):
                       '    "PersistenceFileName": "%s",\n    "AffectedParserPaths": [\n      "test/path/1",\n' \
                       '      "test/path/2"\n    ]\n  },\n  "LogData": {\n    "RawLogData": [\n      " pid="\n    ],\n    ' \
                       '"Timestamps": [\n      %s\n    ],\n    "DetectionTimestamp": %s,\n    "LogLinesCount": 5,\n' \
-                      '    "AnnotatedMatchElement": "match/s1:  pid="\n  }%s\n}\n'
+                      '    "AnnotatedMatchElement": {\n      "match/s1": " pid="\n    }\n  }%s\n}\n'
 
     @classmethod
     def setUpClass(cls):
