@@ -69,6 +69,11 @@ case "$1" in
 		./${1}.sh ${*:2}
 		exit $?
 		;;
+	runHowToEntropyDetector)
+		cd $TESTDIR
+		./${1}.sh ${*:2}
+		exit $?
+		;;
 	runJsonDemo)
 		cd $TESTDIR
 		./${1}.sh ${*:2}
@@ -94,36 +99,43 @@ case "$1" in
 		./${1}.sh ${*:2}
 		exit $?
 		;;
+  runReleaseStringCheck)
+		cd $TESTDIR
+		./${1}.sh ${*:2}
+		exit $?
+		;;
 	ALL)
 		cd $TESTDIR
-		        ./runMypy.sh
-                ./runSuspendModeTest.sh
-                ./runUnittests.sh
-                ./runRemoteControlTest.sh
-                ./runConfAvailableTest.sh
-                ./runAminerDemo.sh demo/aminer/demo-config.py
-                ./runAminerDemo.sh demo/aminer/jsonConverterHandler-demo-config.py
-                ./runAminerDemo.sh demo/aminer/template_config.py
-                ./runAminerDemo.sh demo/aminer/template_config.yml
-                ./runAminerDemo.sh demo/aminer/demo-config.yml
-                ./runAminerEncodingDemo.sh demo/aminer/demo-config.py
-                ./runAminerEncodingDemo.sh demo/aminer/demo-config.yml
-                ./runAminerJsonInputDemo.sh
-                ./runJsonDemo.sh demo/aminerJsonInputDemo/json-aminer-demo.yml
-                ./runJsonDemo.sh demo/aminerJsonInputDemo/json-elastic-demo.yml
-                ./runJsonDemo.sh demo/aminerJsonInputDemo/json-eve-demo.yml
-                ./runJsonDemo.sh demo/aminerJsonInputDemo/json-journal-demo.yml
-                ./runJsonDemo.sh demo/aminerJsonInputDemo/json-wazuh-demo.yml
-                ./runAminerIntegrationTest.sh aminerIntegrationTest.sh config.py
-                ./runAminerIntegrationTest.sh aminerIntegrationTest2.sh config21.py config22.py
-                ./runOfflineMode.sh
-                ./runGettingStarted.sh
-                ./runTryItOut.sh
-                ./runHowToCreateYourOwnSequenceDetector.sh
-                ./runHowToCreateYourOwnFrequencyDetector.sh
-                ./runHowToMissingMatchPathValueDetector.sh
-                ./runCoverageTests.sh
-                exit $?
+		./runMypy.sh
+		./runReleaseStringCheck.sh
+    ./runSuspendModeTest.sh
+    ./runUnittests.sh
+    ./runRemoteControlTest.sh
+    ./runConfAvailableTest.sh
+    ./runAminerDemo.sh demo/aminer/demo-config.py
+    ./runAminerDemo.sh demo/aminer/jsonConverterHandler-demo-config.py
+    ./runAminerDemo.sh demo/aminer/template_config.py
+    ./runAminerDemo.sh demo/aminer/template_config.yml
+    ./runAminerDemo.sh demo/aminer/demo-config.yml
+    ./runAminerEncodingDemo.sh demo/aminer/demo-config.py
+    ./runAminerEncodingDemo.sh demo/aminer/demo-config.yml
+    ./runAminerJsonInputDemo.sh
+    ./runJsonDemo.sh demo/aminerJsonInputDemo/json-aminer-demo.yml
+    ./runJsonDemo.sh demo/aminerJsonInputDemo/json-elastic-demo.yml
+    ./runJsonDemo.sh demo/aminerJsonInputDemo/json-eve-demo.yml
+    ./runJsonDemo.sh demo/aminerJsonInputDemo/json-journal-demo.yml
+    ./runJsonDemo.sh demo/aminerJsonInputDemo/json-wazuh-demo.yml
+    ./runAminerIntegrationTest.sh aminerIntegrationTest.sh config.py
+    ./runAminerIntegrationTest.sh aminerIntegrationTest2.sh config21.py config22.py
+    ./runOfflineMode.sh
+    ./runGettingStarted.sh
+    ./runTryItOut.sh
+    ./runHowToCreateYourOwnSequenceDetector.sh
+    ./runHowToCreateYourOwnFrequencyDetector.sh
+    ./runHowToMissingMatchPathValueDetector.sh
+    ./runHowToEntropyDetector.sh
+    ./runCoverageTests.sh
+    exit $?
 		;;
 	SHELL)
 		bash
@@ -133,7 +145,8 @@ case "$1" in
 		echo "Usage: [ ALL | SHELL | runSuspendModeTest | runUnittests | runAminerDemo | runJsonDemo | runAminerJsonInputDemo "
 		echo "         runAminerIntegrationTest | runOfflineMode | runCoverageTests | runRemoteControlTest | runTryItOut "
 		echo "         runGettingStarted | runHowToCreateYourOwnSequenceDetector | runHowToCreateYourOwnFrequencyDetector"
-		echo "         runHowToMissingMatchPathValueDetector | runAminerEncodingDemo | runMypy | runConfAvailableTest] <options>"
+		echo "         runHowToMissingMatchPathValueDetector | runHowToEntropyDetector | runAminerEncodingDemo | runMypy"
+		echo "         runConfAvailableTest | runReleaseStringCheck ] <options>"
 		exit 1
 		;;
         
