@@ -212,7 +212,7 @@ class AminerRemoteControlExecutionMethods:
             elif '.' in val:
                 try:
                     val = float(val)
-                except:  # skipcq: FLK-E722
+                except ValueError:  # skipcq: FLK-E722
                     pass
         self.REMOTE_CONTROL_RESPONSE = '"%s": %s' % (property_name, val)
 
@@ -326,7 +326,10 @@ class AminerRemoteControlExecutionMethods:
         @param analysis_context the analysis context of the aminer.
         @param destination_file the path to the file in which the config is saved.
         """
-        msg = AminerConfig.save_config(analysis_context, destination_file)
+        if re.match("^(/[^/ ]*)+/?$", destination_file) is not None:
+            msg = AminerConfig.save_config(analysis_context, destination_file)
+        else:
+            msg = f"Exception: {destination_file} is not a valid filename!"
         self.REMOTE_CONTROL_RESPONSE = msg
         logging.getLogger(DEBUG_LOG_NAME).info(msg)
 
@@ -411,6 +414,83 @@ class AminerRemoteControlExecutionMethods:
         except Exception as e:
             self.REMOTE_CONTROL_RESPONSE += "Exception: " + repr(e)
 
+    def print_persistency_event_in_component(self, analysis_context, component_name, event_data):
+        """
+        Prints the persistency specified in event_data of component_name.
+        @param analysis_context the analysis context of the aminer.
+        @param component_name the name to be registered in the analysis_context.
+        @param event_data the event_data for the print_persistency_event method.
+        """
+        component = analysis_context.get_component_by_name(component_name)
+        if component is None:
+            self.REMOTE_CONTROL_RESPONSE += "FAILURE: component '%s' does not exist!" % component
+            return
+        if component.__class__.__name__ not in ["EventFrequencyDetector", "MinimalTransitionTimeDetector",
+                                                "PathValueTimeIntervalDetector"]:
+            self.REMOTE_CONTROL_RESPONSE += \
+                "FAILURE: component class '%s' does not support the print_persistency_event! Only the following classes support it: " \
+                "EventFrequencyDetector, MinimalTransitionTimeDetector and PathValueTimeIntervalDetector." \
+                % component.__class__.__name__
+            return
+        try:
+            msg = component.print_persistence_event("Analysis.%s" % component.__class__.__name__, event_data)
+            self.REMOTE_CONTROL_RESPONSE += msg
+            logging.getLogger(DEBUG_LOG_NAME).info(msg)
+        # skipcq: PYL-W0703
+        except Exception as e:
+            self.REMOTE_CONTROL_RESPONSE += "Exception: " + repr(e)
+
+    def add_to_persistency_event_in_component(self, analysis_context, component_name, event_data):
+        """
+        Add information specified in event_data to the persistency of component_name.
+        @param analysis_context the analysis context of the aminer.
+        @param component_name the name to be registered in the analysis_context.
+        @param event_data the event_data for the add_to_persistency_event method.
+        """
+        component = analysis_context.get_component_by_name(component_name)
+        if component is None:
+            self.REMOTE_CONTROL_RESPONSE += "FAILURE: component '%s' does not exist!" % component
+            return
+        if component.__class__.__name__ not in ["NewMatchPathValueComboDetector", "MinimalTransitionTimeDetector",
+                                                "PathValueTimeIntervalDetector"]:
+            self.REMOTE_CONTROL_RESPONSE += \
+                "FAILURE: component class '%s' does not support the add_to_persistency_event! Only the following classes support it: " \
+                "NewMatchPathValueComboDetector, MinimalTransitionTimeDetector and PathValueTimeIntervalDetector." \
+                % component.__class__.__name__
+            return
+        try:
+            msg = component.add_to_persistence_event("Analysis.%s" % component.__class__.__name__, event_data)
+            self.REMOTE_CONTROL_RESPONSE += msg
+            logging.getLogger(DEBUG_LOG_NAME).info(msg)
+        # skipcq: PYL-W0703
+        except Exception as e:
+            self.REMOTE_CONTROL_RESPONSE += "Exception: " + repr(e)
+
+    def remove_from_persistency_event_in_component(self, analysis_context, component_name, event_data):
+        """
+        Remove information specified in event_data from the persistency of component_name.
+        @param analysis_context the analysis context of the aminer.
+        @param component_name the name to be registered in the analysis_context.
+        @param event_data the event_data for the remove_from_persistency_event method.
+        """
+        component = analysis_context.get_component_by_name(component_name)
+        if component is None:
+            self.REMOTE_CONTROL_RESPONSE += "FAILURE: component '%s' does not exist!" % component
+            return
+        if component.__class__.__name__ not in ["MinimalTransitionTimeDetector", "PathValueTimeIntervalDetector"]:
+            self.REMOTE_CONTROL_RESPONSE += \
+                "FAILURE: component class '%s' does not support the remove_from_persistency_event! Only the following classes support it: "\
+                "MinimalTransitionTimeDetector and PathValueTimeIntervalDetector." \
+                % component.__class__.__name__
+            return
+        try:
+            msg = component.remove_from_persistence_event("Analysis.%s" % component.__class__.__name__, event_data)
+            self.REMOTE_CONTROL_RESPONSE += msg
+            logging.getLogger(DEBUG_LOG_NAME).info(msg)
+        # skipcq: PYL-W0703
+        except Exception as e:
+            self.REMOTE_CONTROL_RESPONSE += "Exception: " + repr(e)
+
     def add_handler_to_atom_filter_and_register_analysis_component(self, analysis_context, atom_handler, component, component_name):
         """
         Add a new component to the analysis_context.
@@ -595,7 +675,7 @@ class AminerRemoteControlExecutionMethods:
 
     def reopen_event_handler_streams(self, analysis_context):
         """Reopen all StreamPrinterEventHandler streams for log rotation."""
-        analysis_context.close_event_handler_streams(reopen=True)
+        analysis_context.close_event_handler_streams(analysis_context.atomizer_factory.event_handler_list, reopen=True)
         msg = "Reopened all StreamPrinterEventHandler streams."
         self.REMOTE_CONTROL_RESPONSE = msg
         logging.getLogger(DEBUG_LOG_NAME).info(msg)
@@ -658,6 +738,6 @@ def _reformat_attr(attr):
     if not isinstance(attr, (list, dict, tuple, set)) and not rep.startswith('"') and not rep.isdecimal():
         try:
             float(rep)
-        except:  # skipcq: FLK-E722
+        except ValueError:  # skipcq: FLK-E722
             rep = '"%s"' % rep
     return rep
