@@ -12,39 +12,33 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
 
-import logging
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.input.InputInterfaces import AtomHandlerInterface
 
 
 class SubhandlerFilter(AtomHandlerInterface):
-    """
-    Handlers of this class pass the received atoms to one or more subhandlers.
-    Depending on configuration, the atom is passed to all subhandlers or only up to the first suitable to handle the atom.
-    """
+    """Handlers of this class pass the received atoms to a list of atom handlers."""
 
     def __init__(self, subhandler_list, stop_when_handled_flag=False):
-        """@param subhandler_list when not None, initialize this filter with the given list of handlers."""
-        if subhandler_list is None:
-            self.subhandler_list = []
-        else:
-            if (not isinstance(subhandler_list, list)) or \
-                    (not all(isinstance(handler, AtomHandlerInterface) for handler in subhandler_list)):
-                msg = 'Only subclasses of AtomHandlerInterface allowed in subhandlerList'
-                logging.getLogger(DEBUG_LOG_NAME).error(msg)
-                raise Exception(msg)
-            self.subhandler_list = [None] * len(subhandler_list)
-            for handler_pos, handler_element in enumerate(subhandler_list):
-                self.subhandler_list[handler_pos] = (handler_element, stop_when_handled_flag)
+        """
+        @param subhandler_list a list of objects implementing the AtomHandlerInterface which are run until the end, if
+               stop_when_handled_flag is False or until an atom handler can handle the log atom.
+        @param stop_when_handled_flag True, if the atom handler processing should stop after successfully receiving the log atom.
+        """
+        super().__init__(
+            mutable_default_args=["subhandler_list"], subhandler_list=subhandler_list, stop_when_handled_flag=stop_when_handled_flag)
 
     def add_handler(self, atom_handler, stop_when_handled_flag=False):
-        """Add a handler to the list of handlers."""
+        """
+        Add a handler to the list of handlers.
+        @param atom_handler an object implementing the AtomHandlerInterface.
+        @param stop_when_handled_flag True, if the atom handler processing should stop after successfully receiving the log atom.
+        """
         self.subhandler_list.append((atom_handler, stop_when_handled_flag))
 
     def receive_atom(self, log_atom):
         """
-        Pass the atom to the subhandlers.
-        @return false when no subhandler was able to handle the atom.
+        Receive a parsed atom and the information about the parser match.
+        @return False when no subhandler was able to handle the atom.
         """
         result = False
         self.log_total += 1
@@ -59,23 +53,23 @@ class SubhandlerFilter(AtomHandlerInterface):
 
 
 class MatchPathFilter(AtomHandlerInterface):
-    """This class just splits incoming matches according to existance of pathes in the match."""
+    """This class just splits incoming matches according to existence of paths in the match."""
 
     def __init__(self, parsed_atom_handler_lookup_list, default_parsed_atom_handler=None):
         """
         Initialize the filter.
-        @param parsed_atom_handler_lookup_list has to contain tuples with search path string and handler. When the handler is None,
+        @param parsed_atom_handler_lookup_list contains tuples with search path string and handler. When the handler is None,
         the filter will just drop a received atom without forwarding.
         @param default_parsed_atom_handler invoke this handler when no handler was found for given match path or do not invoke any
         handler when None.
         """
-        self.parsed_atom_handler_lookup_list = parsed_atom_handler_lookup_list
-        self.default_parsed_atom_handler = default_parsed_atom_handler
+        super().__init__(
+            parsed_atom_handler_lookup_list=parsed_atom_handler_lookup_list, default_parsed_atom_handler=default_parsed_atom_handler)
 
     def receive_atom(self, log_atom):
         """
-        Receive an atom and pass it to the subhandlers.
-        @return False when logAtom did not contain match data or was not forwarded to any handler, True otherwise.
+        Receive a parsed atom and the information about the parser match.
+        @return False when log_atom did not contain match data or was not forwarded to any handler, True otherwise.
         """
         self.log_total += 1
         if log_atom.parser_match is None:
@@ -100,12 +94,13 @@ class MatchValueFilter(AtomHandlerInterface):
     def __init__(self, target_path, parsed_atom_handler_dict, default_parsed_atom_handler=None):
         """
         Initialize the splitter.
+        @param target_path the path to be analyzed in the parser match of the log atom.
+        @param parsed_atom_handler_dict a dictionary of match value to atom handler.
         @param default_parsed_atom_handler invoke this default handler when no value handler was found or do not invoke any handler
         when None.
         """
-        self.target_path = target_path
-        self.parsed_atom_handler_dict = parsed_atom_handler_dict
-        self.default_parsed_atom_handler = default_parsed_atom_handler
+        super().__init__(target_path=target_path, parsed_atom_handler_dict=parsed_atom_handler_dict,
+                         default_parsed_atom_handler=default_parsed_atom_handler)
 
     def receive_atom(self, log_atom):
         """Receive a log atom from a source."""
