@@ -27,7 +27,7 @@ from aminer import AminerConfig
 
 class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
     """
-    This class creates events when a new value combination for a given list of match data pathes were found.
+    This class creates events when a new value combination for a given list of match data paths were found.
     It is similar to the NewMatchPathValueComboDetector basic detector but also provides support for storing meta information about each
     detected value combination, e.g.
     * the first time a tuple was detected using the LogAtom default timestamp.
@@ -38,29 +38,32 @@ class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
     """
 
     def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, persistence_id='Default', allow_missing_values_flag=False,
-                 auto_include_flag=False, tuple_transformation_function=None, output_log_line=True):
+                 learn_mode=False, tuple_transformation_function=None, output_logline=True, stop_learning_time=None,
+                 stop_learning_no_anomaly_time=None):
         """
         Initialize the detector. This will also trigger reading or creation of persistence storage location.
         @param target_path_list the list of values to extract from each match to create the value combination to be checked.
         @param allow_missing_values_flag when set to True, the detector will also use matches, where one of the paths from target_path_list
-        does not refer to an existing parsed data object.
-        @param auto_include_flag when set to True, this detector will report a new value only the first time before including it
-        in the known values set automatically.
+               does not refer to an existing parsed data object.
+        @param learn_mode when set to True, this detector will report a new value only the first time before including it in the known
+               values set automatically.
         @param tuple_transformation_function when not None, this function will be invoked on each extracted value combination list to
-        transform it. It may modify the list directly or create a new one to return it.
+               transform it. It may modify the list directly or create a new one to return it.
+        @param stop_learning_time switch the learn_mode to False after the time.
+        @param stop_learning_no_anomaly_time switch the learn_mode to False after no anomaly was detected for that time.
         """
+        # avoid "defined outside init" issue
+        self.learn_mode, self.stop_learning_timestamp, self.next_persist_time, self.log_success, self.log_total = [None]*5
         self.known_values_dict = {}
-        super(EnhancedNewMatchPathValueComboDetector, self).__init__(aminer_config, target_path_list, anomaly_event_handlers,
-                                                                     persistence_id, allow_missing_values_flag, auto_include_flag)
         self.tuple_transformation_function = tuple_transformation_function
-        self.output_log_line = output_log_line
-        self.aminer_config = aminer_config
+        super().__init__(
+            aminer_config=aminer_config, target_path_list=target_path_list, anomaly_event_handlers=anomaly_event_handlers,
+            persistence_id=persistence_id, allow_missing_values_flag=allow_missing_values_flag, learn_mode=learn_mode,
+            output_logline=output_logline, stop_learning_time=stop_learning_time,
+            stop_learning_no_anomaly_time=stop_learning_no_anomaly_time)
         self.date_string = "%Y-%m-%d %H:%M:%S"
-        self.log_success = 0
-        self.log_total = 0
         self.log_learned_path_value_combos = 0
         self.log_new_learned_values = []
-        self.next_persist_time = None
 
     def load_persistence_data(self):
         """Load the persistence data from storage."""
@@ -70,7 +73,7 @@ class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
             # the first lists to tuples to allow hash operation needed by set.
             for value_tuple, extra_data in persistence_data:
                 self.known_values_dict[tuple(value_tuple)] = extra_data
-            logging.getLogger(DEBUG_LOG_NAME).debug('%s loaded persistence data.', self.__class__.__name__)
+            logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} loaded persistence data.')
 
     def receive_atom(self, log_atom):
         """
@@ -80,6 +83,10 @@ class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
         """
         self.log_total += 1
         match_dict = log_atom.parser_match.get_match_dictionary()
+        if self.learn_mode is True and self.stop_learning_timestamp is not None and \
+                self.stop_learning_timestamp < log_atom.atom_time:
+            logging.getLogger(DEBUG_LOG_NAME).info(f"Stopping learning in the {self.__class__.__name__}.")
+            self.learn_mode = False
         timestamp = log_atom.get_timestamp()
         if timestamp is None:
             timestamp = time.time()
@@ -126,7 +133,7 @@ class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
         analysis_component = {'AffectedLogAtomPaths': self.target_path_list, 'AffectedLogAtomValues': affected_log_atom_values,
                               'Metadata': metadata}
         event_data = {'AnalysisComponent': analysis_component}
-        if (self.auto_include_flag and self.known_values_dict.get(match_value_tuple)[2] == 1) or not self.auto_include_flag:
+        if (self.learn_mode and self.known_values_dict.get(match_value_tuple)[2] == 1) or not self.learn_mode:
             self.log_learned_path_value_combos += 1
             try:
                 data = log_atom.raw_data.decode(AminerConfig.ENCODING)
@@ -134,42 +141,33 @@ class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
                 data = repr(log_atom.raw_data)
             original_log_line_prefix = self.aminer_config.config_properties.get(CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX)
             for listener in self.anomaly_event_handlers:
-                if self.output_log_line:
-                    match_paths_values = {}
-                    for match_path, match_element in match_dict.items():
-                        if isinstance(match_element, list):
-                            match_value = []
-                            for match in match_element:
-                                if isinstance(match.match_object, bytes):
-                                    match_value.append(match.match_object.decode(AminerConfig.ENCODING))
-                                else:
-                                    match_value.append(match.match_object)
-                        else:
-                            match_value = match_element.match_object
-                            if isinstance(match_value, bytes):
-                                match_value = match_value.decode(AminerConfig.ENCODING)
-                        match_paths_values[match_path] = match_value
-                    analysis_component['ParsedLogAtom'] = match_paths_values
-                    sorted_log_lines = [log_atom.parser_match.match_element.annotate_match('') + os.linesep + str(
-                        self.known_values_dict) + os.linesep + original_log_line_prefix + data]
-                else:
-                    sorted_log_lines = [str(self.known_values_dict) + os.linesep + original_log_line_prefix + data]
-                listener.receive_event('Analysis.%s' % self.__class__.__name__, 'New value combination(s) detected', sorted_log_lines,
+                sorted_log_lines = [str(self.known_values_dict) + os.linesep + original_log_line_prefix + data]
+                listener.receive_event(f'Analysis.{self.__class__.__name__}', 'New value combination(s) detected', sorted_log_lines,
                                        event_data, log_atom, self)
-        if self.auto_include_flag and self.next_persist_time is None:
-            self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+            if self.learn_mode and self.stop_learning_timestamp is not None and self.stop_learning_no_anomaly_time is not None:
+                self.stop_learning_timestamp = time.time() + self.stop_learning_no_anomaly_time
         self.log_success += 1
         return True
 
+    def do_timer(self, trigger_time):
+        """Check if current ruleset should be persisted."""
+        if self.next_persist_time is None:
+            return self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+
+        delta = self.next_persist_time - trigger_time
+        if delta <= 0:
+            self.do_persist()
+            delta = self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+            self.next_persist_time = time.time() + delta
+        return delta
+
     def do_persist(self):
         """Immediately write persistence data to storage."""
         persistence_data = []
         for dict_record in self.known_values_dict.items():
             persistence_data.append(dict_record)
         PersistenceUtil.store_json(self.persistence_file_name, persistence_data)
-        self.next_persist_time = None
-        logging.getLogger(DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} persisted data.')
 
     def allowlist_event(self, event_type, event_data, allowlisting_data):
         """
@@ -177,7 +175,7 @@ class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
         @return a message with information about allowlisting
         @throws Exception when allowlisting of this special event using given allowlisting_data was not possible.
         """
-        if event_type != 'Analysis.%s' % self.__class__.__name__:
+        if event_type != f'Analysis.{self.__class__.__name__}':
             msg = 'Event not from this source'
             logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
@@ -187,7 +185,7 @@ class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
             raise Exception(msg)
         current_timestamp = event_data[0]
         self.known_values_dict[event_data[1]] = [current_timestamp, current_timestamp, 1]
-        return 'Allowlisted path(es) %s with %s.' % (', '.join(self.target_path_list), event_data)
+        return f"Allowlisted path(es) {', '.join(self.target_path_list)} with {event_data}."
 
     def log_statistics(self, component_name):
         """
@@ -196,13 +194,13 @@ class EnhancedNewMatchPathValueComboDetector(NewMatchPathValueComboDetector):
         """
         if AminerConfig.STAT_LEVEL == 1:
             logging.getLogger(STAT_LOG_NAME).info(
-                "'%s' processed %d out of %d log atoms successfully and learned %d new value combinations in the last 60"
-                " minutes.", component_name, self.log_success, self.log_total, self.log_learned_path_value_combos)
+                f"'{component_name}' processed {self.log_success} out of {self.log_total} log atoms successfully and learned "
+                f"{self.log_learned_path_value_combos} new value combinations in the last 60 minutes.")
         elif AminerConfig.STAT_LEVEL == 2:
             logging.getLogger(STAT_LOG_NAME).info(
-                "'%s' processed %d out of %d log atoms successfully and learned %d new value combinations in the last 60"
-                " minutes. Following new value combinations were learned: %s", component_name, self.log_success, self.log_total,
-                self.log_learned_path_value_combos, self.log_new_learned_values)
+                f"'{component_name}' processed {self.log_success} out of {self.log_total} log atoms successfully and learned "
+                f"{self.log_learned_path_value_combos} new value combinations in the last 60 minutes. Following new value combinations "
+                f"were learned: {self.log_new_learned_values}")
         self.log_success = 0
         self.log_total = 0
         self.log_learned_path_value_combos = 0
