@@ -17,7 +17,6 @@ import os
 import logging
 
 from aminer.AminerConfig import build_persistence_file_name, KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD, DEBUG_LOG_NAME
-from aminer import AminerConfig
 from aminer.AnalysisChild import AnalysisContext
 from aminer.input.InputInterfaces import AtomHandlerInterface
 from aminer.util import PersistenceUtil
@@ -30,31 +29,36 @@ class MatchValueAverageChangeDetector(AtomHandlerInterface, TimeTriggeredCompone
     Reports are generated if the average of the latest diverges significantly from the values observed before.
     """
 
-    def __init__(self, aminer_config, anomaly_event_handlers, timestamp_path, analyze_path_list, min_bin_elements, min_bin_time,
-                 debug_mode=False, persistence_id='Default', output_log_line=True):
+    time_trigger_class = AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
+
+    def __init__(self, aminer_config, anomaly_event_handlers, timestamp_path, target_path_list, min_bin_elements, min_bin_time,
+                 debug_mode=False, persistence_id='Default', output_logline=True):
         """
         Initialize the detector. This will also trigger reading or creation of persistence storage location.
+        @param aminer_config configuration from analysis_context.
+        @param anomaly_event_handlers for handling events, e.g., print events to stdout.
         @param timestamp_path if not None, use this path value for timestamp based bins.
-        @param analyze_path_list list of match paths to analyze in this detector.
+        @param target_path_list parser paths of values to be analyzed. Multiple paths mean that all values occurring in these paths are
+               considered for value range generation.
         @param min_bin_elements evaluate the latest bin only after at least that number of elements was added to it.
         @param min_bin_time evaluate the latest bin only when the first element is received after min_bin_time has elapsed.
         @param debug_mode if true, generate an analysis report even when average of last bin was within expected range.
+        @param persistence_id name of persistence file.
+        @param output_logline specifies whether the full parsed log atom should be provided in the output.
         """
-        self.anomaly_event_handlers = anomaly_event_handlers
-        self.timestamp_path = timestamp_path
-        self.min_bin_elements = min_bin_elements
-        self.min_bin_time = min_bin_time
-        self.debug_mode = debug_mode
-        self.next_persist_time = None
-        self.persistence_id = persistence_id
-        self.output_log_line = output_log_line
-        self.aminer_config = aminer_config
+        # avoid "defined outside init" issue
+        self.next_persist_time, self.log_success, self.log_total = [None] * 3
+        super().__init__(
+            aminer_config=aminer_config, anomaly_event_handlers=anomaly_event_handlers, timestamp_path=timestamp_path,
+            target_path_list=target_path_list, min_bin_elements=min_bin_elements, min_bin_time=min_bin_time, debug_mode=debug_mode,
+            persistence_id=persistence_id, output_logline=output_logline
+        )
 
         self.persistence_file_name = build_persistence_file_name(aminer_config, self.__class__.__name__, persistence_id)
         PersistenceUtil.add_persistable_component(self)
         persistence_data = PersistenceUtil.load_json(self.persistence_file_name)
         self.stat_data = []
-        for path in analyze_path_list:
+        for path in target_path_list:
             self.stat_data.append((path, [],))
         if persistence_data is not None:
             for val in persistence_data:
@@ -115,60 +119,41 @@ class MatchValueAverageChangeDetector(AtomHandlerInterface, TimeTriggeredCompone
                     a['Old'] = old
                     d['AnalysisData'] = a
                     if analysis_summary == '':
-                        analysis_summary += '"%s": %s' % (path, analysis_data[0])
+                        analysis_summary += f'"{path}": {analysis_data[0]}'
                     else:
                         analysis_summary += os.linesep
-                        analysis_summary += '  "%s": %s' % (path, analysis_data[0])
+                        analysis_summary += f'  "{path}": {analysis_data[0]}'
                     anomaly_scores.append(d)
-            analysis_component = {'AffectedLogAtomPaths': list(value_dict)}
-            if self.output_log_line:
-                match_paths_values = {}
-                for match_path, match_element in log_atom.parser_match.get_match_dictionary().items():
-                    match_value = match_element.match_object
-                    if isinstance(match_value, bytes):
-                        match_value = match_value.decode(AminerConfig.ENCODING)
-                    match_paths_values[match_path] = match_value
-                analysis_component['ParsedLogAtom'] = match_paths_values
-            analysis_component['AnomalyScores'] = anomaly_scores
-            analysis_component['MinBinElements'] = self.min_bin_elements
-            analysis_component['MinBinTime'] = self.min_bin_time
-            analysis_component['DebugMode'] = self.debug_mode
+            analysis_component = {'AffectedLogAtomPaths': list(value_dict),
+                                  'AnomalyScores': anomaly_scores,
+                                  'MinBinElements': self.min_bin_elements,
+                                  'MinBinTime': self.min_bin_time,
+                                  'DebugMode': self.debug_mode}
             event_data = {'AnalysisComponent': analysis_component}
 
-            if self.next_persist_time is None:
-                self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                    KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
-
         if analysis_summary:
             res = [''] * stat_data[2][0]
             res[0] = analysis_summary
             for listener in self.anomaly_event_handlers:
-                listener.receive_event('Analysis.%s' % self.__class__.__name__, 'Statistical data report', res, event_data, log_atom, self)
+                listener.receive_event(f'Analysis.{self.__class__.__name__}', 'Statistical data report', res, event_data, log_atom, self)
         self.log_success += 1
 
-    def get_time_trigger_class(self):  # skipcq: PYL-R0201
-        """
-        Get the trigger class this component should be registered for.
-        This trigger is used only for persistence, so real-time triggering is needed.
-        """
-        return AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
-
     def do_timer(self, trigger_time):
-        """Check current ruleset should be persisted."""
+        """Check if current ruleset should be persisted."""
         if self.next_persist_time is None:
             return self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
         delta = self.next_persist_time - trigger_time
-        if delta < 0:
-            self.next_persist_time = None
+        if delta <= 0:
+            self.do_persist()
             delta = self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+            self.next_persist_time = time.time() + delta
         return delta
 
     def do_persist(self):
         """Immediately write persistence data to storage."""
         PersistenceUtil.store_json(self.persistence_file_name, self.stat_data)
-        self.next_persist_time = None
-        logging.getLogger(DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} persisted data.')
 
     def update(self, stat_data, timestamp_value, value):
         """
@@ -202,7 +187,7 @@ class MatchValueAverageChangeDetector(AtomHandlerInterface, TimeTriggeredCompone
         Perform the analysis and progress from the last bin to the next one.
         @return None when statistical data was as expected and debugging is disabled.
         """
-        logging.getLogger(DEBUG_LOG_NAME).debug('%s performs analysis.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} performs analysis.')
         current_bin = stat_data[3]
         current_average = current_bin[1] / current_bin[0]
         current_variance = (current_bin[2] - (current_bin[1] * current_bin[1]) / current_bin[0]) / (current_bin[0] - 1)
@@ -214,7 +199,7 @@ class MatchValueAverageChangeDetector(AtomHandlerInterface, TimeTriggeredCompone
             stat_data[2] = (current_bin[0], current_bin[1], current_bin[2], current_average, current_variance,)
             stat_data[3] = (0, 0.0, 0.0)
             if self.debug_mode:
-                return 'Initial: n = %d, avg = %s, var = %s' % (current_bin[0], current_average + stat_data[1], current_variance)
+                return f'Initial: n = {current_bin[0]}, avg = {current_average + stat_data[1]}, var = {current_variance}'
         else:
             total_n = old_bin[0] + current_bin[0]
             total_sum = old_bin[1] + current_bin[1]
@@ -225,8 +210,8 @@ class MatchValueAverageChangeDetector(AtomHandlerInterface, TimeTriggeredCompone
             stat_data[3] = (0, 0.0, 0.0)
 
             if (current_variance > 2 * old_bin[4]) or (abs(current_average - old_bin[3]) > old_bin[4]) or self.debug_mode:
-                res = ['Change: new: n = %d, avg = %s, var = %s; old: n = %d, avg = %s, var = %s' % (
-                    current_bin[0], current_average + stat_data[1], current_variance, old_bin[0], old_bin[3] + stat_data[1], old_bin[4]),
-                    current_bin[0], current_average + stat_data[1], current_variance, old_bin[0], old_bin[3] + stat_data[1], old_bin[4]]
+                res = [f'Change: new: n = {current_bin[0]}, avg = {current_average + stat_data[1]}, var = {current_variance}; old: n = '
+                       f'{old_bin[0]}, avg = {old_bin[3] + stat_data[1]}, var = { old_bin[4]}', current_bin[0],
+                       current_average + stat_data[1], current_variance, old_bin[0], old_bin[3] + stat_data[1], old_bin[4]]
                 return res
         return None
