@@ -26,12 +26,20 @@ class MatchValueStreamWriter(AtomHandlerInterface, TimeTriggeredComponentInterfa
     time trigger list.
     """
 
-    def __init__(self, stream, match_value_path_list, separator_string, missing_value_string):
-        """Initialize the writer."""
-        self.stream = stream
-        self.match_value_path_list = match_value_path_list
-        self.separator_string = separator_string
-        self.missing_value_string = missing_value_string
+    time_trigger_class = AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
+
+    def __init__(self, stream, target_path_list, separator, missing_value_string):
+        """
+        Initialize the writer.
+        @param stream the stream on which the match results are written.
+        @param target_path_list parser paths of values to be analyzed. Multiple paths mean that all values occurring in these paths are
+               considered for value range generation.
+        @param separator a string to be added between match values in the output stream.
+        @param missing_value_string a string which is added if no match was found.
+        """
+        # avoid "defined outside init" issue
+        self.log_success, self.log_total = [None]*2
+        super().__init__(stream=stream, target_path_list=target_path_list, separator=separator, missing_value_string=missing_value_string)
 
     def receive_atom(self, log_atom):
         """Forward match value information to the stream."""
@@ -40,9 +48,9 @@ class MatchValueStreamWriter(AtomHandlerInterface, TimeTriggeredComponentInterfa
         add_sep_flag = False
         contains_data = False
         result = b''
-        for path in self.match_value_path_list:
+        for path in self.target_path_list:
             if add_sep_flag:
-                result += self.separator_string
+                result += self.separator
             match = match_dict.get(path)
             if match is None:
                 result += self.missing_value_string
@@ -53,10 +61,10 @@ class MatchValueStreamWriter(AtomHandlerInterface, TimeTriggeredComponentInterfa
                 else:
                     matches.append(match)
                 for match in matches:
-                    result += match.match_string + self.separator_string
+                    result += match.match_string + self.separator
                     contains_data = True
-                if len(self.separator_string) > 0:
-                    result = result[:-len(self.separator_string)]
+                if len(self.separator) > 0:
+                    result = result[:-len(self.separator)]
             add_sep_flag = True
         if contains_data:
             if not isinstance(self.stream, _io.BytesIO):
@@ -67,13 +75,6 @@ class MatchValueStreamWriter(AtomHandlerInterface, TimeTriggeredComponentInterfa
                 self.stream.write(b'\n')
             self.log_success += 1
 
-    def get_time_trigger_class(self):  # skipcq: PYL-R0201
-        """
-        Get the trigger class this component should be registered for.
-        This trigger is used only for persistence, so real-time triggering is needed.
-        """
-        return AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
-
     def do_timer(self, _trigger_time):
         """Flush the timer."""
         self.stream.flush()
