@@ -28,33 +28,44 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
     """
     This class creates events when an expected value is not seen within a given timespan.
     For example because the service was deactivated or logging disabled unexpectedly. This is complementary to the function provided by
-    NewMatchPathValueDetector. For each unique value extracted by target_path_list, a tracking record is added to expected_values_dict.
+    NewMatchPathValueDetector. For each unique value extracted by paths, a tracking record is added to expected_values_dict.
     It stores three numbers: the timestamp the extracted value was last seen, the maximum allowed gap between observations and the next
     alerting time when currently in error state. When in normal (alerting) state, the value is zero.
     """
 
-    def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, persistence_id='Default', auto_include_flag=False,
-                 default_interval=3600, realert_interval=86400, output_log_line=True):
+    time_trigger_class = AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
+
+    def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, persistence_id='Default', learn_mode=False,
+                 default_interval=3600, realert_interval=86400, combine_values=True, output_logline=True, stop_learning_time=None,
+                 stop_learning_no_anomaly_time=None):
         """
         Initialize the detector. This will also trigger reading or creation of persistence storage location.
-        @param target_path_list to extract a source identification value from each logatom.
+        @param aminer_config configuration from analysis_context.
+        @param target_path_list parser paths of values to be analyzed. Multiple paths mean that all values occurring in these paths are
+               considered for value range generation.
+        @param anomaly_event_handlers for handling events, e.g., print events to stdout.
+        @param persistence_id name of persistence file.
+        @param learn_mode specifies whether new expected values should be learned.
+        @param default_interval time in seconds before a value is reported missing. The parameter is applied to the parsed record data time,
+               not the system time. Hence, reports can be delayed when no data is received.
+        @param realert_interval time in seconds before a value is reported missing for a second time. The parameter is applied to the
+               parsed record data time, not the system time. Hence, reports can be delayed when no data is received.
+        @param combine_values if true the combined values are used as identifiers. When false, individual values are checked.
+        @param stop_learning_time switch the learn_mode to False after the time.
+        @param stop_learning_no_anomaly_time switch the learn_mode to False after no anomaly was detected for that time.
         """
-        self.target_path_list = target_path_list
-        self.anomaly_event_handlers = anomaly_event_handlers
-        self.auto_include_flag = auto_include_flag
-        self.default_interval = default_interval
-        self.realert_interval = realert_interval
-        # This timestamps is compared with timestamp values from log atoms for activation of alerting logic. The first timestamp from logs
+        # avoid "defined outside init" issue
+        self.learn_mode, self.stop_learning_timestamp, self.next_persist_time, self.log_success, self.log_total = [None]*5
+        super().__init__(
+            aminer_config=aminer_config, target_path_list=target_path_list, anomaly_event_handlers=anomaly_event_handlers,
+            persistence_id=persistence_id, learn_mode=learn_mode, default_interval=default_interval, realert_interval=realert_interval,
+            output_logline=output_logline, combine_values=combine_values, stop_learning_time=stop_learning_time,
+            stop_learning_no_anomaly_time=stop_learning_no_anomaly_time
+        )
+        # This timestamp is compared with timestamp values from log atoms for activation of alerting logic. The first timestamp from logs
         # above this value will trigger alerting.
         self.next_check_timestamp = 0
         self.last_seen_timestamp = 0
-        self.next_persist_time = None
-        self.output_log_line = output_log_line
-        self.aminer_config = aminer_config
-        self.persistence_id = persistence_id
-
-        self.log_success = 0
-        self.log_total = 0
         self.log_learned_values = 0
         self.log_new_learned_values = []
 
@@ -66,7 +77,8 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
             for key in persistence_data:
                 value = persistence_data[key]
                 if self.target_path_list is not None:  # skipcq: PTC-W0048
-                    if value[3] != self.target_path_list:
+                    if (value[3] not in self.target_path_list and not self.combine_values) or (
+                            value[3] != str(self.target_path_list) and self.combine_values):
                         continue
                 elif self.target_path_list is not None and value[3] not in self.target_path_list:
                     continue
@@ -74,7 +86,7 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
                     value[1] = default_interval
                     value[2] = value[0] + default_interval
                 self.expected_values_dict[key] = value
-            logging.getLogger(DEBUG_LOG_NAME).debug('%s loaded persistence data.', self.__class__.__name__)
+            logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} loaded persistence data.')
         self.analysis_string = 'Analysis.%s'
 
     def receive_atom(self, log_atom):
@@ -82,48 +94,62 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
         Receive a log atom from a source.
         @param log_atom binary raw atom data
         @return True if this handler was really able to handle and process the atom. Depending on this information, the caller
-        may decide if it makes sense passing the atom also to other handlers or to retry later. This behaviour has to be documented
-        at each source implementation sending LogAtoms.
+                may decide if it makes sense passing the atom also to other handlers or to retry later. This behaviour has to be documented
+                at each source implementation sending log atoms.
         """
         self.log_total += 1
+        if self.learn_mode is True and self.stop_learning_timestamp is not None and \
+                self.stop_learning_timestamp < log_atom.atom_time:
+            logging.getLogger(DEBUG_LOG_NAME).info(f"Stopping learning in the {self.__class__.__name__}.")
+            self.learn_mode = False
+
         value = self.get_channel_key(log_atom)
-        if value is None:
+        if value is None or (not value[0] and not value[1]):
             return False
-        target_path, value = value
+        target_paths, value_list = value
+        if isinstance(target_paths, str) and isinstance(value_list, str):
+            target_paths = [target_paths]
+            value_list = [value_list]
         timestamp = log_atom.get_timestamp()
         if timestamp is None:
             timestamp = time.time()
-        detector_info = self.expected_values_dict.get(value)
-        if detector_info is not None:
-            # Just update the last seen value and switch from non-reporting error state to normal state.
-            detector_info[0] = timestamp
-            if detector_info[2] != 0:
-                if timestamp >= detector_info[2]:
-                    detector_info[2] = 0
-                # Delta of this detector might be lower than the default maximum recheck time.
-                self.next_check_timestamp = min(self.next_check_timestamp, timestamp + detector_info[1])
+        for i, target_path in enumerate(target_paths):
+            value = value_list[i]
+            detector_info = self.expected_values_dict.get(value)
+            if detector_info is None and self.learn_mode:
+                self.expected_values_dict[value] = [timestamp, self.default_interval, 0, target_path]
+                self.next_check_timestamp = min(self.next_check_timestamp, timestamp + self.default_interval)
+                self.log_learned_values += 1
+                self.log_new_learned_values.append(value)
+                if self.stop_learning_timestamp is not None and self.stop_learning_no_anomaly_time is not None:
+                    self.stop_learning_timestamp = time.time() + self.stop_learning_no_anomaly_time
 
-        elif self.auto_include_flag:
-            self.expected_values_dict[value] = [timestamp, self.default_interval, 0, target_path]
-            self.next_check_timestamp = min(self.next_check_timestamp, timestamp + self.default_interval)
-            self.log_learned_values += 1
-            self.log_new_learned_values.append(value)
-
-        # Always enforce persistence syncs from time to time, the timestamps in the records change even when no new hosts are added.
-        if self.next_persist_time is None:
-            self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
         self.check_timeouts(timestamp, log_atom)
+
+        for i, target_path in enumerate(target_paths):
+            value = value_list[i]
+            detector_info = self.expected_values_dict.get(value)
+            if detector_info is not None:
+                # Just update the last seen value and switch from non-reporting error state to normal state.
+                detector_info[0] = timestamp
+                if detector_info[2] != 0:
+                    if timestamp >= detector_info[2]:
+                        detector_info[2] = 0
+                    # Delta of this detector might be lower than the default maximum recheck time.
+                    self.next_check_timestamp = min(self.next_check_timestamp, timestamp + detector_info[1])
         self.log_success += 1
         return True
 
     def get_channel_key(self, log_atom):
         """Get the key identifying the channel this log_atom is coming from."""
         value_list = []
+        path_list = []
         for target_path in self.target_path_list:
             match = log_atom.parser_match.get_match_dictionary().get(target_path)
             if match is None:
-                return None
+                if self.combine_values:
+                    return None
+                continue
             matches = []
             if isinstance(match, list):
                 matches = match
@@ -135,7 +161,11 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
                 else:
                     affected_log_atom_values = match.match_object
                 value_list.append(str(affected_log_atom_values))
-        return self.target_path_list, str(value_list)
+                path_list.append(target_path)
+        if self.combine_values:
+            value_list = str(value_list)
+            path_list = str(path_list)
+        return path_list, value_list
 
     def check_timeouts(self, timestamp, log_atom):
         """Check if there was any timeout on a channel, thus triggering event dispatching."""
@@ -160,26 +190,26 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
                         old = self.next_check_timestamp
                         self.next_check_timestamp = min(self.next_check_timestamp, self.last_seen_timestamp - value_overdue_time)
                         if old > self.next_check_timestamp or self.next_check_timestamp < detector_info[2]:
-                            continue
+                            break
                 # avoid early re-alerting
                 if value_overdue_time > 0:
-                    missing_value_list.append([value, value_overdue_time, detector_info[1]])
+                    missing_value_list.append([detector_info[3], value, value_overdue_time, detector_info[1]])
                     # Set the next alerting time.
                     detector_info[2] = self.last_seen_timestamp + self.realert_interval
                     self.expected_values_dict[value] = detector_info
                 # Workaround:
                 # also check for long gaps between same tokens where the last_seen_timestamp gets updated
                 # on the arrival of tokens following a longer gap
-                elif self.last_seen_timestamp > old_last_seen_timestamp + detector_info[1]:
+                elif self.last_seen_timestamp - detector_info[0] > detector_info[1]:
                     value_overdue_time = self.last_seen_timestamp - old_last_seen_timestamp - detector_info[1]
-                    missing_value_list.append([value, value_overdue_time, detector_info[1]])
+                    missing_value_list.append([detector_info[3], value, value_overdue_time, detector_info[1]])
                     # Set the next alerting time.
                     detector_info[2] = self.last_seen_timestamp + self.realert_interval
                     self.expected_values_dict[value] = detector_info
             if missing_value_list:
                 message_part = []
                 affected_log_atom_values = []
-                for value, overdue_time, interval in missing_value_list:
+                for target_path_list, value, overdue_time, interval in missing_value_list:
                     e = {}
                     try:
                         if isinstance(value, list):
@@ -198,32 +228,27 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
                     except UnicodeError:
                         data = repr(value)
                     if self.__class__.__name__ == 'MissingMatchPathValueDetector':
-                        e['TargetPathList'] = self.target_path_list
-                        message_part.append('  %s: %s overdue %ss (interval %s)' % (self.target_path_list, data, overdue_time,
-                                            interval))
+                        e['TargetPathList'] = target_path_list
+                        message_part.append(f'  {target_path_list}: {data} overdue {overdue_time}s (interval {interval})\n')
                     else:
                         target_paths = ''
                         for target_path in self.target_path_list:
                             target_paths += target_path + ', '
                         e['TargetPathList'] = self.target_path_list
-                        message_part.append('  %s: %s overdue %ss (interval %s)' % (target_paths[:-2], data, overdue_time, interval))
+                        message_part.append(f'  {target_paths[:-2]}: {data} overdue {overdue_time}s (interval {interval})\n')
                     e['Value'] = str(value)
                     e['OverdueTime'] = str(overdue_time)
                     e['Interval'] = str(interval)
                     affected_log_atom_values.append(e)
-                analysis_component = {'AffectedLogAtomPaths': list(log_atom.parser_match.get_match_dictionary()),
+                affected_log_atom_paths = []
+                for path in log_atom.parser_match.get_match_dictionary().keys():
+                    if path in self.target_path_list:
+                        affected_log_atom_paths.append(path)
+                analysis_component = {'AffectedLogAtomPaths': affected_log_atom_paths,
                                       'AffectedLogAtomValues': affected_log_atom_values}
-                if self.output_log_line:
-                    match_paths_values = {}
-                    for match_path, match_element in log_atom.parser_match.get_match_dictionary().items():
-                        match_value = match_element.match_object
-                        if isinstance(match_value, bytes):
-                            match_value = match_value.decode(AminerConfig.ENCODING)
-                        match_paths_values[match_path] = match_value
-                    analysis_component['ParsedLogAtom'] = match_paths_values
                 event_data = {'AnalysisComponent': analysis_component}
                 for listener in self.anomaly_event_handlers:
-                    self.send_event_to_handlers(listener, event_data, log_atom, [''.join(message_part)])
+                    self.send_event_to_handlers(listener, event_data, log_atom, [''.join(message_part).strip()])
         return True
 
     def send_event_to_handlers(self, anomaly_event_handler, event_data, log_atom, message_part):
@@ -235,37 +260,28 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
         """Add or overwrite a value to be monitored by the detector."""
         self.expected_values_dict[value] = [self.last_seen_timestamp, interval, 0, target_path]
         self.next_check_timestamp = 0
-        # Explicitely trigger a persistence sync to avoid staying in unsynced state too long when no new received atoms trigger it. But do
-        # not sync immediately, that would make bulk calls to this method quite inefficient.
-        if self.next_persist_time is None:
-            self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
     def remove_check_value(self, value):
         """Remove checks for given value."""
         del self.expected_values_dict[value]
-        logging.getLogger(DEBUG_LOG_NAME).debug('%s removed check value %s.', self.__class__.__name__, str(value))
-
-    def get_time_trigger_class(self):  # skipcq: PYL-R0201
-        """Get the trigger class this component can be registered for. This detector only needs persisteny triggers in real time."""
-        return AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
+        logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} removed check value {str(value)}.')
 
     def do_timer(self, trigger_time):
-        """Check current ruleset should be persisted."""
+        """Check if current ruleset should be persisted."""
         if self.next_persist_time is None:
             return self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+
         delta = self.next_persist_time - trigger_time
-        if delta < 0:
-            PersistenceUtil.store_json(self.persistence_file_name, self.expected_values_dict)
-            self.next_persist_time = None
+        if delta <= 0:
+            self.do_persist()
             delta = self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+            self.next_persist_time = time.time() + delta
         return delta
 
     def do_persist(self):
         """Immediately write persistence data to storage."""
         PersistenceUtil.store_json(self.persistence_file_name, self.expected_values_dict)
-        self.next_persist_time = None
-        logging.getLogger(DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} persisted data.')
 
     def allowlist_event(self, event_type, event_data, allowlisting_data):
         """
@@ -287,7 +303,7 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
             self.remove_check_value(event_data[0])
         else:
             self.set_check_value(event_data[0], new_interval, event_data[1])
-        return "Updated '%s' in '%s' to new interval %d." % (event_data[0], event_data[1], new_interval)
+        return f"Updated '{event_data[0]}' in '{event_data[1]}' to new interval {new_interval}."
 
     def log_statistics(self, component_name):
         """
@@ -296,13 +312,13 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
         """
         if AminerConfig.STAT_LEVEL == 1:
             logging.getLogger(STAT_LOG_NAME).info(
-                "'%s' processed %d out of %d log atoms successfully and learned %d new values in the last 60"
-                " minutes.", component_name, self.log_success, self.log_total, self.log_learned_values)
+                f"'{component_name}' processed {self.log_success} out of {self.log_total} log atoms successfully and learned "
+                f"{self.log_learned_values} new values in the last 60 minutes.)")
         elif AminerConfig.STAT_LEVEL == 2:
             logging.getLogger(STAT_LOG_NAME).info(
-                "'%s' processed %d out of %d log atoms successfully and learned %d new values in the last 60"
-                " minutes. Following new values were learned: %s", component_name, self.log_success, self.log_total,
-                self.log_learned_values, self.log_new_learned_values)
+                f"'{component_name}' processed {self.log_success} out of {self.log_total} log atoms successfully and learned "
+                f"{self.log_learned_values} new values in the last 60 minutes. Following new values were learned: "
+                f"{self.log_new_learned_values}")
         self.log_success = 0
         self.log_total = 0
         self.log_learned_values = 0
