@@ -34,62 +34,66 @@ class NewMatchIdValueComboDetector(AtomHandlerInterface, TimeTriggeredComponentI
     Paths need to be found in log atoms with the same id value in a specific path.
     """
 
+    time_trigger_class = AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
+
     def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, id_path_list, min_allowed_time_diff,
-                 persistence_id='Default', allow_missing_values_flag=False, auto_include_flag=False, output_log_line=True):
+                 persistence_id='Default', allow_missing_values_flag=False, learn_mode=False, output_logline=True,
+                 stop_learning_time=None, stop_learning_no_anomaly_time=None):
         """
         Initialize the detector. This will also trigger reading or creation of persistence storage location.
+        @param aminer_config configuration from analysis_context.
         @param target_path_list the list of values to extract from each match to create the value combination to be checked.
-        @param id_path_list the list of pathes where id values can be stored in all relevant log event types.
+        @param anomaly_event_handlers for handling events, e.g., print events to stdout.
+        @param id_path_list the list of paths where id values can be stored in all relevant log event types.
         @param min_allowed_time_diff the minimum amount of time in seconds after the first appearance of a log atom with a specific id
-        that is waited for other log atoms with the same id to occur. The maximum possible time to keep an incomplete combo
-        is 2*min_allowed_time_diff
-        @param allow_missing_values_flag when set to True, the detector will also use matches, where one of the pathes from target_path_list
-        does not refer to an existing parsed data object.
-        @param auto_include_flag when set to True, this detector will report a new value only the first time before including it
-        in the known values set automatically.
+               that is waited for other log atoms with the same id to occur. The maximum possible time to keep an incomplete combo
+               is 2*min_allowed_time_diff
+        @param persistence_id name of persistence file.
+        @param allow_missing_values_flag when set to True, the detector will also use matches, where one of the paths from target_path_list
+               does not refer to an existing parsed data object.
+        @param learn_mode when set to True, this detector will report a new value only the first time before including it
+               in the known values set automatically.
+        @param output_logline specifies whether the full parsed log atom should be provided in the output.
+        @param stop_learning_time switch the learn_mode to False after the time.
+        @param stop_learning_no_anomaly_time switch the learn_mode to False after no anomaly was detected for that time.
         """
-        self.target_path_list = target_path_list
-        self.anomaly_event_handlers = anomaly_event_handlers
-        self.id_path_list = id_path_list
-        self.min_allowed_time_diff = min_allowed_time_diff
-        self.allow_missing_values_flag = allow_missing_values_flag
-        self.auto_include_flag = auto_include_flag
-        self.output_log_line = output_log_line
-        self.aminer_config = aminer_config
-        self.persistence_id = persistence_id
-
-        self.log_success = 0
-        self.log_total = 0
+        # avoid "defined outside init" issue
+        self.learn_mode, self.stop_learning_timestamp, self.next_persist_time, self.log_success, self.log_total = [None]*5
+        super().__init__(
+            aminer_config=aminer_config, target_path_list=target_path_list, anomaly_event_handlers=anomaly_event_handlers,
+            id_path_list=id_path_list, min_allowed_time_diff=min_allowed_time_diff, persistence_id=persistence_id,
+            allow_missing_values_flag=allow_missing_values_flag, learn_mode=learn_mode, output_logline=output_logline,
+            stop_learning_time=stop_learning_time, stop_learning_no_anomaly_time=stop_learning_no_anomaly_time
+        )
         self.log_learned_path_value_combos = 0
         self.log_new_learned_values = []
 
         self.persistence_file_name = build_persistence_file_name(aminer_config, self.__class__.__name__, persistence_id)
-        self.next_persist_time = None
-        self.load_persistence_data()
-        PersistenceUtil.add_persistable_component(self)
-
-        self.id_dict_current = {}
-        self.id_dict_old = {}
-        self.next_shift_time = None
-
-    def load_persistence_data(self):
-        """Load the persistence data from storage."""
         persistence_data = PersistenceUtil.load_json(self.persistence_file_name)
         self.known_values = []
         if persistence_data is not None:
             # Combinations are stored as list of dictionaries
             for record in persistence_data:
                 self.known_values.append(record)
-            logging.getLogger(DEBUG_LOG_NAME).debug('%s loaded persistence data.', self.__class__.__name__)
+            logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} loaded persistence data.')
+        PersistenceUtil.add_persistable_component(self)
+
+        self.id_dict_current = {}
+        self.id_dict_old = {}
+        self.next_shift_time = None
 
     def receive_atom(self, log_atom):
         """
         Receive on parsed atom and the information about the parser match.
         @return True if a value combination was extracted and checked against the list of known combinations, no matter if the checked
-        values were new or not.
+                values were new or not.
         """
         self.log_total += 1
         match_dict = log_atom.parser_match.get_match_dictionary()
+        if self.learn_mode is True and self.stop_learning_timestamp is not None and \
+                self.stop_learning_timestamp < log_atom.atom_time:
+            logging.getLogger(DEBUG_LOG_NAME).info(f"Stopping learning in the {self.__class__.__name__}.")
+            self.learn_mode = False
 
         id_match_element = None
         for id_path in self.id_path_list:
@@ -123,7 +127,7 @@ class NewMatchIdValueComboDetector(AtomHandlerInterface, TimeTriggeredComponentI
         else:
             id_match_object = id_match_element.match_object
 
-        # Find dictionary containing id and create ref to old or current dict (side-effects)
+        # Find dictionary containing id and create ref to old or current dict (side effects)
         id_dict = None
         if id_match_object in self.id_dict_current:
             id_dict = self.id_dict_current
@@ -163,13 +167,12 @@ class NewMatchIdValueComboDetector(AtomHandlerInterface, TimeTriggeredComponentI
         """Process an entry from the id_dict."""
         if id_dict_entry not in self.known_values:
             # Combo is unknown, process and raise anomaly
-            if self.auto_include_flag:
+            if self.learn_mode:
                 self.known_values.append(id_dict_entry)
                 self.log_learned_path_value_combos += 1
                 self.log_new_learned_values.append(id_dict_entry)
-                if self.next_persist_time is None:
-                    self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                        KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+                if self.stop_learning_timestamp is not None and self.stop_learning_no_anomaly_time is not None:
+                    self.stop_learning_timestamp = time.time() + self.stop_learning_no_anomaly_time
 
             analysis_component = {'AffectedLogAtomValues': [str(i) for i in list(id_dict_entry.values())]}
             event_data = {'AnalysisComponent': analysis_component}
@@ -178,38 +181,31 @@ class NewMatchIdValueComboDetector(AtomHandlerInterface, TimeTriggeredComponentI
             except UnicodeError:
                 data = repr(log_atom.raw_data)
             original_log_line_prefix = self.aminer_config.config_properties.get(CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX)
-            if self.output_log_line:
+            if self.output_logline:
                 sorted_log_lines = [log_atom.parser_match.match_element.annotate_match('') + os.linesep + repr(
                     id_dict_entry) + os.linesep + original_log_line_prefix + data]
             else:
                 sorted_log_lines = [repr(id_dict_entry) + os.linesep + original_log_line_prefix + data]
             for listener in self.anomaly_event_handlers:
-                listener.receive_event('Analysis.%s' % self.__class__.__name__, 'New value combination(s) detected', sorted_log_lines,
+                listener.receive_event(f'Analysis.{self.__class__.__name__}', 'New value combination(s) detected', sorted_log_lines,
                                        event_data, log_atom, self)
 
-    def get_time_trigger_class(self):  # skipcq: PYL-R0201
-        """
-        Get the trigger class this component should be registered for.
-        This trigger is used only for persistence, so real-time triggering is needed.
-        """
-        return AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
-
     def do_timer(self, trigger_time):
-        """Check current ruleset should be persisted."""
+        """Check if current ruleset should be persisted."""
         if self.next_persist_time is None:
             return self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
         delta = self.next_persist_time - trigger_time
-        if delta < 0:
+        if delta <= 0:
             self.do_persist()
             delta = self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+            self.next_persist_time = time.time() + delta
         return delta
 
     def do_persist(self):
         """Immediately write persistence data to storage."""
         PersistenceUtil.store_json(self.persistence_file_name, self.known_values)
-        self.next_persist_time = None
-        logging.getLogger(DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} persisted data.')
 
     def allowlist_event(self, event_type, event_data, allowlisting_data):
         """
@@ -217,7 +213,7 @@ class NewMatchIdValueComboDetector(AtomHandlerInterface, TimeTriggeredComponentI
         @return a message with information about allowlisting
         @throws Exception when allowlisting of this special event using given allowlisting_data was not possible.
         """
-        if event_type != 'Analysis.%s' % self.__class__.__name__:
+        if event_type != f'Analysis.{self.__class__.__name__}':
             msg = 'Event not from this source'
             logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
@@ -227,7 +223,7 @@ class NewMatchIdValueComboDetector(AtomHandlerInterface, TimeTriggeredComponentI
             raise Exception(msg)
         if event_data not in self.known_values:
             self.known_values.append(event_data)
-        return 'Allowlisted path(es) %s with %s.' % (', '.join(self.target_path_list), event_data)
+        return f"Allowlisted path(es) {', '.join(self.target_path_list)} with {event_data}."
 
     def log_statistics(self, component_name):
         """
@@ -236,13 +232,13 @@ class NewMatchIdValueComboDetector(AtomHandlerInterface, TimeTriggeredComponentI
         """
         if AminerConfig.STAT_LEVEL == 1:
             logging.getLogger(STAT_LOG_NAME).info(
-                "'%s' processed %d out of %d log atoms successfully and learned %d new value combinations in the last 60"
-                " minutes.", component_name, self.log_success, self.log_total, self.log_learned_path_value_combos)
+                f"'{component_name}' processed {self.log_success} out of {self.log_total} log atoms successfully and learned "
+                f"{self.log_learned_path_value_combos} new value combinations in the last 60 minutes.")
         elif AminerConfig.STAT_LEVEL == 2:
             logging.getLogger(STAT_LOG_NAME).info(
-                "'%s' processed %d out of %d log atoms successfully and learned %d new value combinations in the last 60"
-                " minutes. Following new value combinations were learned: %s", component_name, self.log_success, self.log_total,
-                self.log_learned_path_value_combos, self.log_new_learned_values)
+                f"'{component_name}' processed {self.log_success} out of {self.log_total} log atoms successfully and learned "
+                f"{self.log_learned_path_value_combos} new value combinations in the last 60 minutes. Following new value combinations "
+                f"were learned: {self.log_new_learned_values}")
         self.log_success = 0
         self.log_total = 0
         self.log_learned_path_value_combos = 0
