@@ -19,8 +19,10 @@ import copy
 import numpy as np
 import logging
 import os
+import time
 from aminer import AminerConfig
-from aminer.AminerConfig import STAT_LEVEL, STAT_LOG_NAME, CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX
+from aminer.AminerConfig import DEBUG_LOG_NAME, STAT_LEVEL, STAT_LOG_NAME, CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX,\
+    KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD
 from aminer.AnalysisChild import AnalysisContext
 from aminer.util import PersistenceUtil
 from aminer.input.InputInterfaces import AtomHandlerInterface
@@ -30,36 +32,42 @@ from aminer.util.TimeTriggeredComponentInterface import TimeTriggeredComponentIn
 class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
     """This class creates events if event or value occurrence counts are outliers in PCA space."""
 
+    time_trigger_class = AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
+
     def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, window_size, min_anomaly_score, min_variance, num_windows,
-                 persistence_id='Default', auto_include_flag=False, output_log_line=True, ignore_list=None, constraint_list=None):
+                 persistence_id='Default', learn_mode=False, output_logline=True, ignore_list=None, constraint_list=None,
+                 stop_learning_time=None, stop_learning_no_anomaly_time=None):
         """
         Initialize the detector. This will also trigger reading or creation of persistence storage location.
         @param aminer_config configuration from analysis_context.
         @param target_path_list parser paths of values to be analyzed. Multiple paths mean that values are analyzed as separate
-        dimensions. When no paths are specified, the events given by the full path list are analyzed (one dimension).
+               dimensions. When no paths are specified, the events given by the full path list are analyzed (one dimension).
         @param anomaly_event_handlers for handling events, e.g., print events to stdout.
         @param window_size the length of the time window for counting in seconds.
         @param min_anomaly_score the minimum computed outlier score for reporting anomalies. Scores are scaled by training data, i.e.,
-        reasonable minimum scores are >1 to detect outliers with respect to currently trained PCA matrix.
+               reasonable minimum scores are >1 to detect outliers with respect to currently trained PCA matrix.
         @param min_variance the minimum variance covered by the principal components in range [0, 1].
         @param num_windows the number of time windows in the sliding window approach. Total covered time span = window_size * num_windows.
-        @param persistence_id name of persistency document.
-        @param auto_include_flag specifies whether new count measurements are added to the PCA count matrix.
-        @param output_log_line specifies whether the full parsed log atom should be provided in the output.
+        @param persistence_id name of persistence file.
+        @param learn_mode specifies whether new count measurements are added to the PCA count matrix.
+        @param output_logline specifies whether the full parsed log atom should be provided in the output.
         @param ignore_list list of paths that are not considered for analysis, i.e., events that contain one of these paths are
-        omitted. The default value is [] as None is not iterable.
-        @param constrain_list list of paths that have to be present in the log atom to be analyzed.
+               omitted. The default value is [] as None is not iterable.
+        @param constraint_list list of paths that have to be present in the log atom to be analyzed.
+        @param stop_learning_time switch the learn_mode to False after the time.
+        @param stop_learning_no_anomaly_time switch the learn_mode to False after no anomaly was detected for that time.
         """
-        self.target_path_list = target_path_list
-        self.anomaly_event_handlers = anomaly_event_handlers
-        self.auto_include_flag = auto_include_flag
-        self.next_persist_time = None
-        self.output_log_line = output_log_line
-        self.aminer_config = aminer_config
-        self.persistence_id = persistence_id
-        self.block_time = window_size
-        self.anomaly_score_threshold = min_anomaly_score
-        self.variance_threshold = min_variance
+        # avoid "defined outside init" issue
+        self.learn_mode, self.stop_learning_timestamp, self.next_persist_time, self.log_success, self.log_total = [None]*5
+        super().__init__(
+            mutable_default_args=["ignore_list", "constraint_list"], aminer_config=aminer_config, target_path_list=target_path_list,
+            anomaly_event_handlers=anomaly_event_handlers, window_size=window_size, min_anomaly_score=min_anomaly_score,
+            min_variance=min_variance, num_windows=num_windows, persistence_id=persistence_id, learn_mode=learn_mode,
+            output_logline=output_logline, ignore_list=ignore_list, constraint_list=constraint_list, stop_learning_time=stop_learning_time,
+            stop_learning_no_anomaly_time=stop_learning_no_anomaly_time
+        )
+        # skipcq: PYL-W0511
+        # ToDo: an exception should be thrown instead of this check.
         if num_windows < 3:
             logging.getLogger(AminerConfig.DEBUG_LOG_NAME).warning('num_windows must be >= 3!')
             self.num_windows = 3
@@ -67,18 +75,16 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
             self.num_windows = num_windows
         self.first_log = True
         self.start_time = 0
-        self.constraint_list = constraint_list
         self.event_count_matrix = []
         self.feature_list = []
         self.ecm = None
-        if self.constraint_list is None:
-            self.constraint_list = []
-        self.ignore_list = ignore_list
-        if self.ignore_list is None:
-            self.ignore_list = []
-        self.log_total = 0
-        self.log_success = 0
         self.log_windows = 0
+        self.pca_ecm = None
+        self.eigen_vectors = None
+        # number of components (n_comp): how many components should be used for reconstruction
+        self.n_comp = None
+        # Calculate Anomaly-Score (Reconstruction Error) for the whole dataset
+        self.loss = None
 
         self.persistence_file_name = AminerConfig.build_persistence_file_name(aminer_config, self.__class__.__name__, persistence_id)
         PersistenceUtil.add_persistable_component(self)
@@ -101,6 +107,10 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
         """Receive parsed atom and the information about the parser match."""
         parser_match = log_atom.parser_match
         self.log_total += 1
+        if self.learn_mode is True and self.stop_learning_timestamp is not None and \
+                self.stop_learning_timestamp < log_atom.atom_time:
+            logging.getLogger(DEBUG_LOG_NAME).info(f"Stopping learning in the {self.__class__.__name__}.")
+            self.learn_mode = False
 
         # Skip paths from ignore list.
         for ignore_path in self.ignore_list:
@@ -113,16 +123,16 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
             self.first_log = False
 
         current_time = log_atom.get_timestamp()
-        while current_time >= (self.start_time + self.block_time):
+        while current_time >= (self.start_time + self.window_size):
             # PCA computation only possible when at least 3 vectors are present
             if len(self.event_count_matrix) >= 3:
-                anomalyScore = self.anomalyScore()
-                if anomalyScore > self.anomaly_score_threshold:
+                anomaly_score = self.anomaly_score()
+                if anomaly_score > self.min_anomaly_score:
                     try:
                         data = log_atom.raw_data.decode(AminerConfig.ENCODING)
                     except UnicodeError:
                         data = repr(log_atom.raw_data)
-                    if self.output_log_line:
+                    if self.output_logline:
                         original_log_line_prefix = self.aminer_config.config_properties.get(
                             CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX)
                         sorted_log_lines = [log_atom.parser_match.match_element.annotate_match('') + os.linesep + original_log_line_prefix +
@@ -137,15 +147,15 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
                         affected_values.append(list(count_dict.keys()))
                         affected_counts.append(list(count_dict.values()))
                     analysis_component = {'AffectedLogAtomPaths': affected_paths, 'AffectedLogAtomValues': affected_values,
-                                          'AffectedValueCounts': affected_counts, 'AnomalyScore': anomalyScore[0]}
+                                          'AffectedValueCounts': affected_counts, 'AnomalyScore': anomaly_score[0]}
                     event_data = {'AnalysisComponent': analysis_component}
                     for listener in self.anomaly_event_handlers:
-                        listener.receive_event('Analysis.%s' % self.__class__.__name__, 'PCA anomaly detected',
-                                               sorted_log_lines, event_data, log_atom, self)
+                        listener.receive_event(f'Analysis.{self.__class__.__name__}', 'PCA anomaly detected', sorted_log_lines, event_data,
+                                               log_atom, self)
             self.log_windows += 1
 
             # Add new values to matrix in learn mode
-            if self.auto_include_flag is True:
+            if self.learn_mode is True:
                 if len(self.event_count_matrix) >= self.num_windows:
                     del self.event_count_matrix[0]
                 self.event_count_matrix.append(copy.deepcopy(self.event_count_vector))
@@ -153,9 +163,11 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
                 if len(self.event_count_matrix) >= 3:
                     self.repair_dict()
                     self.compute_pca()
+                if self.stop_learning_timestamp is not None and self.stop_learning_no_anomaly_time is not None:
+                    self.stop_learning_timestamp = time.time() + self.stop_learning_no_anomaly_time
 
             # Set window end time for next iteration
-            self.start_time += self.block_time
+            self.start_time += self.window_size
             # Reset count vector for next time window
             self.reset_event_count_vector()
 
@@ -174,7 +186,7 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
             else:
                 self.event_count_vector[''][log_event] = 1
         else:
-            # Event is defined by values in paths
+            # Event is defined by values in target_path_list
             all_values_none = True
             for path in self.target_path_list:
                 match = parser_match.get_match_dictionary().get(path)
@@ -201,7 +213,6 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
                         self.event_count_vector[path] = {value: 1}
             if all_values_none is True:
                 return
-
         self.log_success += 1
 
     def compute_pca(self):
@@ -221,23 +232,23 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
             matrix.append(row)
         self.ecm = np.array(matrix)
 
-        # Principial Component Analysis (PCA)
+        # Principal Component Analysis (PCA)
         normalized_ecm = (self.ecm - self.ecm.mean()) / self.ecm.std()
         covariance_matrix = np.cov(normalized_ecm.T)
         eigen_values, eigen_vectors = np.linalg.eigh(covariance_matrix)
         self.pca_ecm = normalized_ecm @ eigen_vectors
         self.eigen_vectors = eigen_vectors
 
-        # number of components (nComp): how many components should be used for reconstruction
-        self.nComp = self.get_nComp(eigen_values)
+        # number of components (n_comp): how many components should be used for reconstruction
+        self.n_comp = self.get_n_comp(eigen_values)
 
-        # PCA Inverse with only these components which describes the variance_threshold
-        pca_inverse = self.pca_ecm[:, :self.nComp] @ eigen_vectors[:self.nComp, :]
+        # PCA Inverse with only these components which describes the min_variance
+        pca_inverse = self.pca_ecm[:, :self.n_comp] @ eigen_vectors[:self.n_comp, :]
 
         # Calculate Anomaly-Score (Reconstruction Error) for the whole dataset
         self.loss = np.sum((normalized_ecm - pca_inverse)**2, axis=1)
 
-    def anomalyScore(self):
+    def anomaly_score(self):
         """Calculate the anomalyscore for current event_count_vector."""
         # convert the event_count_vector into an array
         ecv = self.vector2array()
@@ -248,12 +259,11 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
         # calculate the reduced pca for current log-sequence with given eigen_vectors
         pca_ecv = normalized_ecv @ self.eigen_vectors
         # calculate the pca_inverse with reduced number of components / do reconstruction
-        pca_inverse_ecv = pca_ecv[:, :self.nComp] @ self.eigen_vectors[:self.nComp, :]
+        pca_inverse_ecv = pca_ecv[:, :self.n_comp] @ self.eigen_vectors[:self.n_comp, :]
         # calculate the reconstruction error / anomaly score
         loss = np.sum((normalized_ecv - pca_inverse_ecv)**2, axis=1)
         # scale the reconstruction error with the min, max of ecm-loss
         loss = (loss - np.min(self.loss)) / (np.max(self.loss) - np.min(self.loss))
-
         return loss
 
     def vector2array(self):
@@ -263,10 +273,9 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
             for feature, value in event.items():
                 if feature in self.feature_list:
                     vector.append(value)
-
         return np.array(vector)
 
-    def get_nComp(self, eigen_values):
+    def get_n_comp(self, eigen_values):
         """Return the number of components, which describe the variance threshold."""
         # Calculate the explained variance on each of components
         variance_explained = []
@@ -275,9 +284,8 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
         # Calculate the cumulative explained variance (np.cumsum)
         cumulative_variance_explained = np.cumsum(variance_explained)
         for n, i in enumerate(cumulative_variance_explained):
-            if i > (self.variance_threshold*100):
+            if i > (self.min_variance * 100):
                 return n
-
         return None
 
     def repair_dict(self):
@@ -298,30 +306,22 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
             for value in events:
                 events[value] = 0
 
-    def get_time_trigger_class(self):  # skipcq: PYL-R0201
-        """
-        Get the trigger class this component should be registered for.
-        This trigger is used only for persistence, so real-time triggering is needed.
-        """
-        return AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
-
     def do_timer(self, trigger_time):
-        """Check current ruleset should be persisted."""
+        """Check if current ruleset should be persisted."""
         if self.next_persist_time is None:
-            return 600
+            return self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
         delta = self.next_persist_time - trigger_time
-        if delta < 0:
+        if delta <= 0:
             self.do_persist()
-            delta = 600
-
+            delta = self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
+            self.next_persist_time = time.time() + delta
         return delta
 
     def do_persist(self):
         """Immediately write persistence data to storage."""
-        if self.auto_include_flag is True:
+        if self.learn_mode is True:
             PersistenceUtil.store_json(self.persistence_file_name, list(self.event_count_matrix))
-        self.next_persist_time = None
 
     def allowlist_event(self, event_type, event_data, allowlisting_data):
         """
@@ -329,7 +329,7 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
         @return a message with information about allowlisting
         @throws Exception when allowlisting of this special event using given allowlisting_data was not possible.
         """
-        if event_type != 'Analysis.%s' % self.__class__.__name__:
+        if event_type != f'Analysis.{self.__class__.__name__}':
             msg = 'Event not from this source'
             logging.getLogger(AminerConfig.DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
@@ -339,7 +339,7 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
             raise Exception(msg)
         if event_data not in self.constraint_list:
             self.constraint_list.append(event_data)
-        return 'Allowlisted path %s.' % event_data
+        return f'Allowlisted path {event_data}.'
 
     def blocklist_event(self, event_type, event_data, blocklisting_data):
         """
@@ -347,7 +347,7 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
         @return a message with information about blocklisting
         @throws Exception when blocklisting of this special event using given blocklisting_data was not possible.
         """
-        if event_type != 'Analysis.%s' % self.__class__.__name__:
+        if event_type != f'Analysis.{self.__class__.__name__}':
             msg = 'Event not from this source'
             logging.getLogger(AminerConfig.DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
@@ -357,7 +357,7 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
             raise Exception(msg)
         if event_data not in self.ignore_list:
             self.ignore_list.append(event_data)
-        return 'Blocklisted path %s.' % event_data
+        return f'Blocklisted path {event_data}.'
 
     def log_statistics(self, component_name):
         """
@@ -366,12 +366,12 @@ class PCADetector(AtomHandlerInterface, TimeTriggeredComponentInterface):
         """
         if STAT_LEVEL == 1:
             logging.getLogger(STAT_LOG_NAME).info(
-                "'%s' processed %d out of %d log atoms successfully in %d time windows in the last 60"
-                " minutes.", component_name, self.log_success, self.log_total, self.log_windows)
+                f"'{component_name}' processed {self.log_success} out of {self.log_total} log atoms successfully in {self.log_windows} "
+                f"time windows in the last 60 minutes.")
         elif STAT_LEVEL == 2:
             logging.getLogger(STAT_LOG_NAME).info(
-                "'%s' processed %d out of %d log atoms successfully in %d time windows in the last 60"
-                " minutes.", component_name, self.log_success, self.log_total, self.log_windows)
+                f"'{component_name}' processed {self.log_success} out of {self.log_total} log atoms successfully in {self.log_windows} "
+                f"time windows in the last 60 minutes.")
         self.log_success = 0
         self.log_total = 0
         self.log_windows = 0
