@@ -88,8 +88,8 @@ class MatchRule(metaclass=abc.ABCMeta):
     def log_statistics(self, rule_id):
         """Log statistics of an MatchRule. Override this method for more sophisticated statistics output of the MatchRule."""
         if AminerConfig.STAT_LEVEL > 0:
-            logging.getLogger(STAT_LOG_NAME).info("Rule '%s' processed %d out of %d log atoms successfully in the last 60"
-                                                  " minutes.", rule_id, self.log_success, self.log_total)
+            logging.getLogger(STAT_LOG_NAME).info(f"Rule '{rule_id}' processed {self.log_success} out of {self.log_total} log atoms"
+                                                  f" successfully in the last 60 minutes.")
         self.log_success = 0
         self.log_total = 0
         if hasattr(self, 'sub_rules'):
@@ -222,17 +222,17 @@ class ValueDependentDelegatedMatchRule(MatchRule):
     The result of this rule is the result of the selected delegation rule.
     """
 
-    def __init__(self, value_path_list, rule_lookup_dict, default_rule=None, match_action=None):
+    def __init__(self, target_path_list, rule_lookup_dict, default_rule=None, match_action=None):
         """
         Create the rule.
         @param list with value paths that are used to extract the lookup keys for ruleLookupDict. If value lookup fails, None
         will be used for lookup.
         @param rule_lookup_dict dictionary with tuple containing values for valuePathList as key and target rule as value.
-        @param default_rule when not none, this rule will be executed as default. Otherwise when rule lookup failed, False will
+        @param default_rule when not none, this rule will be executed as default. Otherwise, when rule lookup failed, False will
         be returned unconditionally.
         @param match_action if None, no action is performed.
         """
-        self.value_path_list = value_path_list
+        self.target_path_list = target_path_list
         self.rule_lookup_dict = rule_lookup_dict
         self.default_rule = default_rule
         self.match_action = match_action
@@ -245,7 +245,7 @@ class ValueDependentDelegatedMatchRule(MatchRule):
         self.log_total += 1
         match_dict = log_atom.parser_match.get_match_dictionary()
         value_list = []
-        for path in self.value_path_list:
+        for path in self.target_path_list:
             value_element = match_dict.get(path)
             if value_element is not None:
                 value_list.append(value_element.match_object)
@@ -286,20 +286,20 @@ class NegationMatchRule(MatchRule):
         return True
 
     def __str__(self):
-        return 'not %s' % self.sub_rule
+        return f'not {self.sub_rule}'
 
 
 class PathExistsMatchRule(MatchRule):
-    """Match elements of this class return true when the given path was found in the parsed match data."""
+    """Match elements of this class return true when the given target_path was found in the parsed match data."""
 
-    def __init__(self, path, match_action=None):
-        self.path = path
+    def __init__(self, target_path, match_action=None):
+        self.target_path = target_path
         self.match_action = match_action
 
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
-        if self.path in log_atom.parser_match.get_match_dictionary():
+        if self.target_path in log_atom.parser_match.get_match_dictionary():
             if self.match_action is not None:
                 self.match_action.match_action(log_atom)
             self.log_success += 1
@@ -307,26 +307,29 @@ class PathExistsMatchRule(MatchRule):
         return False
 
     def __str__(self):
-        return 'hasPath(%s)' % self.path
+        return f'hasPath({self.target_path})'
 
 
 class ValueMatchRule(MatchRule):
-    """Match elements of this class return true when the given path exists and has exactly the given parsed value."""
+    """Match elements of this class return true when the given target_path exists and has exactly the given parsed value."""
 
-    def __init__(self, path, value, match_action=None):
-        self.path = path
+    def __init__(self, target_path, value, match_action=None):
+        self.target_path = target_path
         self.value = value
         self.match_action = match_action
 
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
-        test_value = log_atom.parser_match.get_match_dictionary().get(self.path, None)
+        test_value = log_atom.parser_match.get_match_dictionary().get(self.target_path, None)
         if test_value is not None:
-            if isinstance(self.value, bytes) and not isinstance(test_value.match_object, bytes) and test_value.match_object is not None:
+            if isinstance(self.value, bytes) and isinstance(test_value.match_object, str) and test_value.match_object is not None:
                 test_value.match_object = test_value.match_object.encode()
-            elif not isinstance(self.value, bytes) and isinstance(test_value.match_object, bytes) and self.value is not None:
+            elif isinstance(self.value, str) and isinstance(test_value.match_object, bytes) and self.value is not None:
                 self.value = self.value.encode()
+            elif not isinstance(self.value, type(test_value.match_object)):
+                raise TypeError(f"The type of the value of the ValueMatchRule does not match the test_value. value: {type(self.value)}, "
+                                f"test_value: {type(test_value.match_object)}")
         if (test_value is not None) and (test_value.match_object == self.value):
             if self.match_action is not None:
                 self.match_action.match_action(log_atom)
@@ -337,22 +340,22 @@ class ValueMatchRule(MatchRule):
     def __str__(self):
         if isinstance(self.value, bytes):
             self.value = self.value.decode()
-        return 'value(%s)==%s' % (self.path, self.value)
+        return f'value({self.target_path})=={self.value}'
 
 
 class ValueListMatchRule(MatchRule):
     """Match elements of this class return true when the given path exists and has exactly one of the values included in the value list."""
 
-    def __init__(self, path, value_list, match_action=None):
-        self.path = path
-        self.value_list = value_list
+    def __init__(self, target_path, target_value_list, match_action=None):
+        self.target_path = target_path
+        self.target_value_list = target_value_list
         self.match_action = match_action
 
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
-        test_value = log_atom.parser_match.get_match_dictionary().get(self.path)
-        if (test_value is not None) and (test_value.match_object in self.value_list):
+        test_value = log_atom.parser_match.get_match_dictionary().get(self.target_path)
+        if (test_value is not None) and (test_value.match_object in self.target_value_list):
             if self.match_action is not None:
                 self.match_action.match_action(log_atom)
             self.log_success += 1
@@ -360,14 +363,14 @@ class ValueListMatchRule(MatchRule):
         return False
 
     def __str__(self):
-        return 'value(%s) in %s' % (' '.join([str(value) for value in self.value_list]), self.path)
+        return f"value({' '.join([str(value) for value in self.target_value_list])}) in {self.target_path}"
 
 
 class ValueRangeMatchRule(MatchRule):
-    """Match elements of this class return true when the given path exists and the value is included in [lower, upper] range."""
+    """Match elements of this class return true when the given target_path exists and the value is included in [lower, upper] range."""
 
-    def __init__(self, path, lower_limit, upper_limit, match_action=None):
-        self.path = path
+    def __init__(self, target_path, lower_limit, upper_limit, match_action=None):
+        self.target_path = target_path
         self.lower_limit = lower_limit
         self.upper_limit = upper_limit
         self.match_action = match_action
@@ -375,7 +378,7 @@ class ValueRangeMatchRule(MatchRule):
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
-        test_value = log_atom.parser_match.get_match_dictionary().get(self.path, None)
+        test_value = log_atom.parser_match.get_match_dictionary().get(self.target_path, None)
         if test_value is None:
             return False
         test_value = test_value.match_object
@@ -387,14 +390,14 @@ class ValueRangeMatchRule(MatchRule):
         return False
 
     def __str__(self):
-        return 'value(%s) inrange (%s, %s)' % (self.path, self.lower_limit, self.upper_limit)
+        return f'value({self.target_path}) inrange ({self.lower_limit}, {self.upper_limit})'
 
 
 class StringRegexMatchRule(MatchRule):
     """Elements of this class return true when the given path exists and the string repr of the value matches the regular expression."""
 
-    def __init__(self, path, match_regex, match_action=None):
-        self.path = path
+    def __init__(self, target_path, match_regex, match_action=None):
+        self.target_path = target_path
         self.match_regex = match_regex
         self.match_action = match_action
 
@@ -402,7 +405,7 @@ class StringRegexMatchRule(MatchRule):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self. log_total += 1
         # Use the class object as marker for nonexisting entries
-        test_value = log_atom.parser_match.get_match_dictionary().get(self.path, None)
+        test_value = log_atom.parser_match.get_match_dictionary().get(self.target_path, None)
         if (test_value is None) or (self.match_regex.match(test_value.match_string) is None):
             return False
         if self.match_action is not None:
@@ -411,22 +414,22 @@ class StringRegexMatchRule(MatchRule):
         return True
 
     def __str__(self):
-        return 'string(%s) =regex= %s' % (self.path, self.match_regex.pattern)
+        return f'string({self.target_path}) =regex= {self.match_regex.pattern}'
 
 
 class ModuloTimeMatchRule(MatchRule):
     """
     Match elements of this class return true when the following conditions are met.
-    The given path exists, denotes a datetime object and the seconds since 1970 from that date modulo the given value are included in
+    The given target_path exists, denotes a datetime object and the seconds since 1970 from that date modulo the given value are included in
     [lower, upper] range.
     """
 
-    def __init__(self, path, seconds_modulo, lower_limit, upper_limit, match_action=None, tzinfo=None):
+    def __init__(self, target_path, seconds_modulo, lower_limit, upper_limit, match_action=None, tzinfo=None):
         """
-        @param path the path to the datetime object to use to evaluate the modulo time rules on.
+        @param target_path the target_path to the datetime object to use to evaluate the modulo time rules on.
         When None, the default timestamp associated with the match is used.
         """
-        self.path = path
+        self.target_path = target_path
         self.seconds_modulo = seconds_modulo
         self.lower_limit = lower_limit
         self.upper_limit = upper_limit
@@ -439,10 +442,10 @@ class ModuloTimeMatchRule(MatchRule):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
         test_value = None
-        if self.path is None:
+        if self.target_path is None:
             test_value = log_atom.get_timestamp()
         else:
-            time_match = log_atom.parser_match.get_match_dictionary().get(self.path, None)
+            time_match = log_atom.parser_match.get_match_dictionary().get(self.target_path, None)
             if time_match is None:
                 return False
             test_value = time_match.match_object + datetime.datetime.now(self.tzinfo).utcoffset().total_seconds()
@@ -465,16 +468,17 @@ class ValueDependentModuloTimeMatchRule(MatchRule):
     [lower, upper] range selected by values from the match.
     """
 
-    def __init__(self, path, seconds_modulo, value_path_list, limit_lookup_dict, default_limit=None, match_action=None, tzinfo=None):
+    def __init__(
+            self, target_path, seconds_modulo, target_path_list, limit_lookup_dict, default_limit=None, match_action=None, tzinfo=None):
         """
-        @param path the path to the datetime object to use to evaluate the modulo time rules on.
+        @param target_path the target_path to the datetime object to use to evaluate the modulo time rules on.
         When None, the default timestamp associated with the match is used.
         @param default_limit use this default limit when limit lookup failed. Without a default limit, a failed lookup will cause
         the rule not to match.
         """
-        self.path = path
+        self.target_path = target_path
         self.seconds_modulo = seconds_modulo
-        self.value_path_list = value_path_list
+        self.target_path_list = target_path_list
         self.limit_lookup_dict = limit_lookup_dict
         self.default_limit = default_limit
         self.match_action = match_action
@@ -487,7 +491,7 @@ class ValueDependentModuloTimeMatchRule(MatchRule):
         self.log_total += 1
         match_dict = log_atom.parser_match.get_match_dictionary()
         value_list = []
-        for path in self.value_path_list:
+        for path in self.target_path_list:
             value_element = match_dict.get(path)
             if value_element is not None:
                 value_list.append(value_element.match_object)
@@ -501,10 +505,10 @@ class ValueDependentModuloTimeMatchRule(MatchRule):
             return False
 
         test_value = None
-        if self.path is None:
+        if self.target_path is None:
             test_value = log_atom.get_timestamp()
         else:
-            time_match = log_atom.parser_match.get_match_dictionary().get(self.path, None)
+            time_match = log_atom.parser_match.get_match_dictionary().get(self.target_path, None)
             if time_match is None:
                 return False
             test_value = time_match.match_object + datetime.datetime.now(self.tzinfo).utcoffset().total_seconds()
@@ -526,14 +530,14 @@ class IPv4InRFC1918MatchRule(MatchRule):
     This could also be done by distinct range match elements, but as this kind of matching is common, have an own element for it.
     """
 
-    def __init__(self, path, match_action=None):
-        self.path = path
+    def __init__(self, target_path, match_action=None):
+        self.target_path = target_path
         self.match_action = match_action
 
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
-        match_element = log_atom.parser_match.get_match_dictionary().get(self.path)
+        match_element = log_atom.parser_match.get_match_dictionary().get(self.target_path)
         if (match_element is None) or not isinstance(match_element.match_object, int):
             return False
         value = match_element.match_object
@@ -545,7 +549,7 @@ class IPv4InRFC1918MatchRule(MatchRule):
         return False
 
     def __str__(self):
-        return 'hasPath(%s)' % self.path
+        return f'hasPath({self.target_path})'
 
 
 class DebugMatchRule(MatchRule):
@@ -557,20 +561,20 @@ class DebugMatchRule(MatchRule):
 
     def __init__(self, debug_match_result=False, match_action=None):
         self.debug_match_result = debug_match_result
-        self.matchAction = match_action
+        self.match_action = match_action
 
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
-        print('Rules.DebugMatchRule: triggered while handling "%s"' % repr(log_atom.parser_match.match_element.match_string),
+        print(f'Rules.DebugMatchRule: triggered while handling "{repr(log_atom.parser_match.match_element.match_string)}"',
               file=sys.stderr)
-        if self.matchAction is not None:
-            self.matchAction.match_action(log_atom)
+        if self.match_action is not None:
+            self.match_action.match_action(log_atom)
         self.log_success += 1
         return self.debug_match_result
 
     def __str__(self):
-        return '%s' % self.debug_match_result
+        return f'{self.debug_match_result}'
 
 
 class DebugHistoryMatchRule(MatchRule):
