@@ -30,21 +30,26 @@ class TimeCorrelationViolationDetector(AtomHandlerInterface, TimeTriggeredCompon
     This is used to implement checks as depicted in http://dx.doi.org/10.1016/j.cose.2014.09.006
     """
 
-    def __init__(self, aminer_config, ruleset, anomaly_event_handlers, persistence_id='Default', output_log_line=True):
+    time_trigger_class = AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
+
+    def __init__(self, aminer_config, ruleset, anomaly_event_handlers, persistence_id='Default', output_logline=True):
         """
         Initialize the detector. This will also trigger reading or creation of persistence storage location.
+        @param aminer_config configuration from analysis_context.
         @param ruleset a list of MatchRule rules with appropriate CorrelationRules attached as actions.
+        @param anomaly_event_handlers for handling events, e.g., print events to stdout.
+        @param persistence_id name of persistence file.
+        @param output_logline specifies whether the full parsed log atom should be provided in the output.
         """
-        self.aminer_config = aminer_config
-        self.event_classification_ruleset = ruleset
-        self.anomaly_event_handlers = anomaly_event_handlers
-        self.next_persist_time = time.time() + self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
-        self.persistence_id = persistence_id
-        self.output_log_line = output_log_line
+        self.next_persist_time, self.log_success, self.log_total = [None]*3
+        super().__init__(
+            aminer_config=aminer_config, ruleset=ruleset, anomaly_event_handlers=anomaly_event_handlers, persistence_id=persistence_id,
+            output_logline=output_logline
+        )
         self.last_log_atom = None
 
         event_correlation_set = set()
-        for rule in self.event_classification_ruleset:
+        for rule in self.ruleset:
             if rule.match_action.artefact_a_rules is not None:
                 event_correlation_set |= set(rule.match_action.artefact_a_rules)
             if rule.match_action.artefact_b_rules is not None:
@@ -58,28 +63,22 @@ class TimeCorrelationViolationDetector(AtomHandlerInterface, TimeTriggeredCompon
         """Receive a parsed atom and evaluate all the classification rules and event triggering on violations."""
         self.log_total += 1
         self.last_log_atom = log_atom
-        for rule in self.event_classification_ruleset:
+        for rule in self.ruleset:
             rule.match(log_atom)
         self.log_success += 1
 
-    def get_time_trigger_class(self):
-        """
-        Get the trigger class this component should be registered for.
-        This trigger is used mainly for persistence, so real-time triggering is needed. Use also real-time triggering for analysis: usually
-        events for violations (timeouts) are generated when receiving newer atoms. This is just the fallback periods of input silence.
-        """
-        return AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
-
     def do_timer(self, trigger_time):
         """Check for any rule violations and if the current ruleset should be persisted."""
         # Persist the state only quite infrequently: As most correlation rules react in timeline of seconds, the persisted data will most
         # likely be unsuitable to catch lost events. So persistence is mostly to capture the correlation rule context, e.g. the history
         # of loglines matched before.
-        if self.next_persist_time - trigger_time < 0:
+        if self.next_persist_time - trigger_time <= 0:
             self.do_persist()
+            self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
+                KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
         # Check all correlation rules, generate single events for each violated rule, possibly containing multiple records. As we might
-        # be processing historic data, the timestamp last seen is unknown here. Hence rules not receiving newer events might not notice
+        # be processing historic data, the timestamp last seen is unknown here. Hence, rules not receiving newer events might not notice
         # for a long time, that they hold information about correlation impossible to fulfil. Take the newest timestamp of any rule
         # and use it for checking.
         newest_timestamp = 0.0
@@ -92,9 +91,8 @@ class TimeCorrelationViolationDetector(AtomHandlerInterface, TimeTriggeredCompon
                 continue
             self.last_log_atom.set_timestamp(trigger_time)
             r = {'RuleId': rule.rule_id, 'MinTimeDelta': rule.min_time_delta, 'MaxTimeDelta': rule.max_time_delta,
-                 'MaxArtefactsAForSingleB': rule.max_artefacts_a_for_single_b, 'ArtefactMatchParameters': rule.artefact_match_parameters,
-                 'HistoryAEvents': rule.history_a_events, 'HistoryBEvents': rule.history_b_events,
-                 'LastTimestampSeen': rule.last_timestamp_seen}
+                 'ArtefactMatchParameters': rule.artefact_match_parameters, 'HistoryAEvents': rule.history_a_events,
+                 'HistoryBEvents': rule.history_b_events, 'LastTimestampSeen': rule.last_timestamp_seen}
             history = {'MaxItems': rule.correlation_history.max_items}
             h = []
             for item in rule.correlation_history.history:
@@ -104,14 +102,13 @@ class TimeCorrelationViolationDetector(AtomHandlerInterface, TimeTriggeredCompon
             analysis_component = {'Rule': r, 'CheckResult': check_result, 'NewestTimestamp': newest_timestamp}
             event_data = {'AnalysisComponent': analysis_component}
             for listener in self.anomaly_event_handlers:
-                listener.receive_event('Analysis.%s' % self.__class__.__name__, 'Correlation rule "%s" violated' % rule.rule_id,
+                listener.receive_event(f'Analysis.{self.__class__.__name__}', f'Correlation rule "{rule.rule_id}" violated',
                                        [check_result[0]], event_data, self.last_log_atom, self)
         return 10.0
 
     def do_persist(self):
         """Immediately write persistence data to storage."""
-        self.next_persist_time = time.time() + self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
-        logging.getLogger(DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug(f'{self.__class__.__name__} persisted data.')
 
     def log_statistics(self, component_name):
         """
@@ -119,7 +116,7 @@ class TimeCorrelationViolationDetector(AtomHandlerInterface, TimeTriggeredCompon
         @param component_name the name of the component which is printed in the log line.
         """
         super().log_statistics(component_name)
-        for i, rule in enumerate(self.event_classification_ruleset):
+        for i, rule in enumerate(self.ruleset):
             rule.log_statistics(component_name + '.' + rule.__class__.__name__ + str(i))
 
 
@@ -147,21 +144,23 @@ class EventClassSelector(Rules.MatchAction):
 class CorrelationRule:
     """
     This class defines a correlation rule to match artefacts A and B.
-    A hidden event A* always triggers at least one artefact A and the the hidden event B*, thus triggering also at least one artefact B.
+    A hidden event A* always triggers at least one artefact A and the hidden event B*, thus triggering also at least one artefact B.
     """
 
-    def __init__(self, rule_id, min_time_delta, max_time_delta, max_artefacts_a_for_single_b=1, artefact_match_parameters=None):
+    def __init__(self, rule_id, min_time_delta, max_time_delta, artefact_match_parameters=None):
         """
         Create the correlation rule.
-        @param artefact_match_parameters if not none, two artefacts A and B will be only treated as correlated when all the
-        parsed artefact attributes identified by the list of attribute path tuples match.
+        @param rule_id a unique identifier of the rule.
         @param min_time_delta minimal delta in seconds, that artefact B may be observed after artefact A. Negative values are allowed
-        as artefact B may be found before A.
+               as artefact B may be found before A.
+        @param max_time_delta maximum delta in seconds, that artefact B may be observed after artefact A. Negative values are allowed
+               as artefact B may be found before A.
+        @param artefact_match_parameters if not none, two artefacts A and B will be only treated as correlated when all the
+               parsed artefact attributes identified by the list of attribute path tuples match.
         """
         self.rule_id = rule_id
         self.min_time_delta = min_time_delta
         self.max_time_delta = max_time_delta
-        self.max_artefacts_a_for_single_b = max_artefacts_a_for_single_b
         self.artefact_match_parameters = artefact_match_parameters
         self.history_a_events = []
         self.history_b_events = []
@@ -210,8 +209,8 @@ class CorrelationRule:
                         if isinstance(violation_line, bytes):
                             violation_line = violation_line.decode()
                             if num_violations <= max_violations:
-                                violation_message += 'FAIL: B-Event for \"%s\" (%s) was found too early!\n' % (
-                                                     violation_line, a_event[2].action_id)
+                                violation_message += f'FAIL: B-Event for \"{violation_line}\" ({a_event[2].action_id}) was found too' \
+                                                     f' early!\n'
                             violation_logs.append(violation_line)
                             del self.history_a_events[a_pos]
                             del self.history_b_events[b_pos]
@@ -226,8 +225,8 @@ class CorrelationRule:
                     if isinstance(violation_line, bytes):
                         violation_line = violation_line.decode()
                         if num_violations <= max_violations:
-                            violation_message += 'FAIL: B-Event for \"%s\" (%s) was not found in time!\n' % (
-                                                 violation_line, a_event[2].action_id)
+                            violation_message += f'FAIL: B-Event for \"{violation_line}\" ({ a_event[2].action_id}) was not found in' \
+                                                 f' time!\n'
                         violation_logs.append(violation_line)
                         del self.history_a_events[a_pos]
                         del self.history_b_events[b_pos]
@@ -243,8 +242,8 @@ class CorrelationRule:
                         if isinstance(violation_line, bytes):
                             violation_line = violation_line.decode()
                             if num_violations <= max_violations:
-                                violation_message += 'FAIL: \"%s\" (%s) %s is not equal %s\n' % (
-                                    violation_line, a_event[2].action_id, a_event[check_pos], b_event[check_pos])
+                                violation_message += f'FAIL: \"{violation_line}\" ({a_event[2].action_id}) {a_event[check_pos]} is not' \
+                                                     f' equal {b_event[check_pos]}\n'
                             violation_logs.append(violation_line)
                             del self.history_a_events[a_pos]
                             del self.history_b_events[b_pos]
@@ -279,8 +278,7 @@ class CorrelationRule:
                 if isinstance(violation_line, bytes):
                     violation_line = violation_line.decode()
                     if num_violations <= max_violations:
-                        violation_message += 'FAIL: B-Event for \"%s\" (%s) was not found in time!\n' % (
-                                             violation_line, a_event[2].action_id)
+                        violation_message += f'FAIL: B-Event for \"{violation_line}\" ({a_event[2].action_id}) was not found in time!\n'
                     violation_logs.append(violation_line)
                     del self.history_a_events[a_pos]
                     deleted = True
@@ -289,12 +287,11 @@ class CorrelationRule:
                 break
 
         if num_violations > max_violations:
-            violation_message += '... (%d more)\n' % (num_violations - max_violations)
+            violation_message += f'... ({num_violations - max_violations} more)\n'
         if num_violations != 0 and len(self.correlation_history.get_history()) > 0:
             violation_message += 'Historic examples:\n'
             for record in self.correlation_history.get_history():
-                violation_message += '  "%s" (%s) ==> "%s" (%s)\n' % (
-                    record[0].decode(), record[1], record[2].decode(), record[3])
+                violation_message += f'  "{record[0].decode()}" ({record[1]}) ==> "{record[2].decode()}" ({record[3]})\n'
 
         if num_violations == 0:
             return None
