@@ -54,20 +54,20 @@ class FileLogDataResource(LogDataResource):
         self.total_consumed_length = 0
         # Create a hash for repositioning. There is no need to be cryptographically secure here: if upstream can manipulate the content,
         # to provoke hash collisions, correct positioning would not matter anyway.
-        # skipcq: PTC-W1003
+        # skipcq: PTC-W1003, BAN-B324
         self.repositioning_digest = hashlib.md5()
 
         if (log_stream_fd != -1) and (repositioning_data is not None):
             if repositioning_data[0] != self.stat_data.st_ino:
-                msg = 'Not attempting to reposition on %s, inode number mismatch' % encode_byte_string_as_string(self.log_resource_name)
+                msg = f'Not attempting to reposition on {encode_byte_string_as_string(self.log_resource_name)}, inode number mismatch'
                 logging.getLogger(DEBUG_LOG_NAME).warning(msg)
                 print(msg, file=sys.stderr)
             elif repositioning_data[1] > self.stat_data.st_size:
-                msg = 'Not attempting to reposition on %s, file size too small' % encode_byte_string_as_string(self.log_resource_name)
+                msg = f'Not attempting to reposition on {encode_byte_string_as_string(self.log_resource_name)}, file size too small'
                 logging.getLogger(DEBUG_LOG_NAME).warning(msg)
                 print(msg, file=sys.stderr)
             else:
-                # skipcq: PTC-W1003
+                # skipcq: PTC-W1003, BAN-B324
                 hash_algo = hashlib.md5()
                 length = repositioning_data[1]
                 while length != 0:
@@ -77,8 +77,8 @@ class FileLogDataResource(LogDataResource):
                     else:
                         block = os.read(self.log_file_fd, default_buffer_size)
                     if not block:
-                        msg = 'Not attempting to reposition on %s, file shrunk while reading' % encode_byte_string_as_string(
-                            self.log_resource_name)
+                        msg = f'Not attempting to reposition on {encode_byte_string_as_string(self.log_resource_name)}, file shrunk while' \
+                              f' reading'
                         logging.getLogger(DEBUG_LOG_NAME).warning(msg)
                         print(msg, file=sys.stderr)
                         break
@@ -91,7 +91,7 @@ class FileLogDataResource(LogDataResource):
                         self.total_consumed_length = repositioning_data[1]
                         self.repositioning_digest = hash_algo
                     else:
-                        msg = 'Not attempting to reposition on %s, digest changed' % encode_byte_string_as_string(self.log_resource_name)
+                        msg = f'Not attempting to reposition on {encode_byte_string_as_string(self.log_resource_name)}, digest changed'
                         logging.getLogger(DEBUG_LOG_NAME).warning(msg)
                         print(msg, file=sys.stderr)
                         length = -1
@@ -117,16 +117,16 @@ class FileLogDataResource(LogDataResource):
             log_file_fd = SecureOSFunctions.secure_open_file(self.log_resource_name[7:], os.O_RDONLY)
             stat_data = os.fstat(log_file_fd)
         except OSError as openOsError:
-            msg = 'OSError occurred in FileLogDataResource.open(). Error message: %s' % openOsError
+            msg = f'OSError occurred in FileLogDataResource.open(). Error message: {openOsError}'
             logging.getLogger(DEBUG_LOG_NAME).error(msg)
             if log_file_fd != -1:
                 os.close(log_file_fd)
             if openOsError.errno == errno.ENOENT:
                 return False
             raise
-        if not stat.S_ISREG(stat_data.st_mode):
+        if not stat.S_ISREG(stat_data.st_mode) and not stat.S_ISFIFO(stat_data.st_mode):
             os.close(log_file_fd)
-            msg = 'Attempting to open non-regular file %s as file' % encode_byte_string_as_string(self.log_resource_name)
+            msg = f'Attempting to open non-regular file {encode_byte_string_as_string(self.log_resource_name)} as file'
             print(msg, file=sys.stderr)
             logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
@@ -180,7 +180,7 @@ class UnixSocketLogDataResource(LogDataResource):
     The characteristics of this type of resource is, that reopening works only after end of stream of was reached.
     """
 
-    # skipcq: PYL-W0231
+    # skipcq: PYL-W0231, PYL-W0613
     def __init__(self, log_resource_name, log_stream_fd, default_buffer_size=1 << 16, repositioning_data=None):
         """
         Create a new unix socket type resource.
@@ -218,8 +218,8 @@ class UnixSocketLogDataResource(LogDataResource):
             log_socket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
             log_socket.connect(self.log_resource_name[7:])
         except socket.error as socketError:
-            logging.getLogger(DEBUG_LOG_NAME).error('OSError occurred in UnixSocketLogDataResource.open(). Error message: %s',
-                                                    socketError.msg)
+            logging.getLogger(DEBUG_LOG_NAME).error(
+                f'OSError occurred in UnixSocketLogDataResource.open(). Error message: {socketError.msg}')
             if log_socket is not None:
                 log_socket.close()
             if socketError.errno in (errno.ENOENT, errno.ECONNREFUSED):
@@ -252,6 +252,7 @@ class UnixSocketLogDataResource(LogDataResource):
         self.total_consumed_length += length
         self.buffer = self.buffer[length:]
 
+    # skipcq: PYL-R0201
     def get_repositioning_data(self):
         """Get the data for repositioning the stream. The returned structure has to be JSON serializable."""
         return None
@@ -346,7 +347,7 @@ class LogStream:
                 return self.log_data_resource.get_file_descriptor()
 
             # This is a clear protocol violation (see StreamAtomizer documentation): When at EOF, 0 is no valid return value.
-            msg = 'Procotol violation by %s detected, flushing data' % self.stream_atomizer.__class__.__name__
+            msg = f'Procotol violation by {self.stream_atomizer.__class__.__name__} detected, flushing data'
             logging.getLogger(DEBUG_LOG_NAME).critical(msg)
             print('FATAL: ' + msg, file=sys.stderr)
             consumed_length = len(self.log_data_resource.buffer)
