@@ -17,12 +17,10 @@ import sys
 import time
 import logging
 import locale
-from typing import Union, List, Set, Optional
-from dateutil.parser import parse
+from typing import Union, List, Set
 from datetime import timezone, datetime
 
 from aminer.AminerConfig import DEBUG_LOG_NAME
-from aminer import AminerConfig
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 from aminer.parsing.MatchElement import MatchElement
 
@@ -79,97 +77,54 @@ class DateTimeModelElement(ModelElementInterface):
 
     # skipcq: PYL-W0613
     def __init__(self, element_id: str, date_format: bytes, time_zone: timezone = None, text_locale: Union[str, tuple] = None,
-                 start_year: int = None, max_time_jump_seconds: int = 86400):
+                 start_year: int = None, max_time_jump_seconds: int = 86400, timestamp_scale: int = 1):
         """
         Create a DateTimeModelElement to parse dates using a custom, timezone and locale-aware implementation similar to strptime.
+        @param element_id an identifier for the ModelElement which is shown in the path.
         @param date_format, is a byte string that represents the date format for parsing, see Python strptime specification for
-        available formats. Supported format specifiers are:
-            * %b: month name in current locale
-            * %d: day in month, can be space or zero padded when followed by separator or at end of string.
-            * %f: fraction of seconds (the digits after the the ".")
-            * %H: hours from 00 to 23
-            * %M: minutes
-            * %m: two digit month number
-            * %S: seconds
-            * %s: seconds since the epoch (1970-01-01)
-            * %Y: 4 digit year number
-            * %z: detect and parse timezone strings like UTC, CET, +0001, etc. automatically.
-        Common formats are:
-            * "%b %d %H:%M:%S" e.g. for "Nov 19 05:08:43"
+               available formats. Supported format specifiers are:
+                 * %b: month name in current locale
+                 * %d: day in month, can be space or zero padded when followed by separator or at end of string.
+                 * %f: fraction of seconds (the digits after the the ".")
+                 * %H: hours from 00 to 23
+                 * %M: minutes
+                 * %m: two digit month number
+                 * %S: seconds
+                 * %s: seconds since the epoch (1970-01-01)
+                 * %Y: 4 digit year number
+                 * %z: detect and parse timezone strings like UTC, CET, +0001, etc. automatically.
+               Common formats are:
+                 * "%b %d %H:%M:%S" e.g. for "Nov 19 05:08:43"
+                 * "%d.%m.%YT%H:%M:%S" e.g. for "07.02.2019T11:40:00"
+                 * "%d.%m.%Y %H:%M:%S.%f" e.g. for "07.02.2019 11:40:00.123456"
+                 * "%d.%m.%Y %H:%M:%S%z" e.g. for "07.02.2019 11:40:00+0000" or "07.02.2019 11:40:00 UTC"
+                 * "%d.%m.%Y" e.g. for "07.02.2019"
+                 * "%H:%M:%S" e.g. for "11:40:23"
         @param time_zone the timezone for parsing the values or UTC when None.
         @param text_locale the locale to use for parsing the day, month names or None to use the default locale. The locale must be a tuple
-        of (locale, encoding) or a string.
+               of (locale, encoding) or a string.
         @param start_year when parsing date records without any year information, assume this is the year of the first value parsed.
         @param max_time_jump_seconds for detection of year wraps with date formats missing year information, also the current time
-        of values has to be tracked. This value defines the window within that the time may jump between two matches. When not
-        within that window, the value is still parsed, corrected to the most likely value but does not change the detection year.
+               of values has to be tracked. This value defines the window within that the time may jump between two matches. When not
+               within that window, the value is still parsed, corrected to the most likely value but does not change the detection year.
+        @param timestamp_scale scales the seconds in %s to get seconds (=1), milliseconds (=1000), microseconds (=1000000), etc.
         """
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-        self.time_zone = time_zone
+        self.text_locale = text_locale
+        super().__init__(element_id, date_format=date_format, time_zone=time_zone, text_locale=text_locale, start_year=start_year,
+                         max_time_jump_seconds=max_time_jump_seconds, timestamp_scale=timestamp_scale)
         if time_zone is None:
             self.time_zone = timezone.utc
-        self.text_locale = text_locale
-        if text_locale is not None:
-            if not isinstance(text_locale, str) and not isinstance(text_locale, tuple):
-                msg = "text_locale has to be of the type string or of the type tuple and have the length 2. (locale, encoding)"
-                logging.getLogger(DEBUG_LOG_NAME).error(msg)
-                raise TypeError(msg)
-            if isinstance(text_locale, tuple) and len(text_locale) != 2:
-                msg = "text_locale has to be of the type string or of the type tuple and have the length 2. (locale, encoding)"
-                logging.getLogger(DEBUG_LOG_NAME).error(msg)
-                raise ValueError(msg)
-            try:
-                old_locale = locale.getdefaultlocale()
-                if old_locale != text_locale:
-                    locale.setlocale(locale.LC_ALL, text_locale)
-                    logging.getLogger(DEBUG_LOG_NAME).info("Changed time locale from %s to %s.", text_locale, "".join(text_locale))
-            except locale.Error:
-                msg = "text_locale %s is not installed!" % text_locale
-                logging.getLogger(DEBUG_LOG_NAME).error(msg)
-                raise locale.Error(msg)
-        # Make sure that dateFormat is valid and extract the relevant parts from it.
+        # Make sure that date_format is valid and extract the relevant parts from it.
         self.format_has_year_flag = False
         self.format_has_tz_specifier = False
         self.date_format_parts: Union[List[Union[bytes, tuple]]] = []
-        self.date_format = date_format
-        if not isinstance(date_format, bytes):
-            msg = "date_format has to be of the type bytes."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(date_format) <= 1:
-            msg = "At least one date_format specifier must be defined."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
         self.scan_date_format(date_format)
 
-        if start_year is not None and not isinstance(start_year, int) or isinstance(start_year, bool):
-            msg = "start_year has to be of the type integer."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
         if (not self.format_has_year_flag) and (start_year is None):
             self.start_year = time.gmtime(None).tm_year
         elif start_year is None:  # this is needed so start_year is at any point an integer. (instead of being None)
             self.start_year = 0
-        else:
-            self.start_year = start_year
 
-        if max_time_jump_seconds is not None and not isinstance(max_time_jump_seconds, int) or isinstance(max_time_jump_seconds, bool):
-            msg = "max_time_jump_seconds has to be of the type integer."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if max_time_jump_seconds <= 0:
-            msg = "max_time_jump_seconds must not be lower than 1 second."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.max_time_jump_seconds = max_time_jump_seconds
         self.last_parsed_seconds = 0
         self.epoch_start_time = datetime.fromtimestamp(0, self.time_zone)
 
@@ -222,7 +177,7 @@ class DateTimeModelElement(ModelElementInterface):
                     scan_pos = next_param_pos
                     continue
                 else:
-                    msg = "Unknown dateformat specifier %s" % repr(param_type_code)
+                    msg = f"Unknown dateformat specifier {repr(param_type_code)}"
                     logging.getLogger(DEBUG_LOG_NAME).error(msg)
                     raise ValueError(msg)
             if isinstance(new_element, bytes):
@@ -232,7 +187,7 @@ class DateTimeModelElement(ModelElementInterface):
                     date_format_parts.append(new_element)
             else:
                 if new_element[0] in date_format_type_set:
-                    msg = "Multiple format specifiers for type %d" % new_element[0]
+                    msg = f"Multiple format specifiers for type {new_element[0]}"
                     logging.getLogger(DEBUG_LOG_NAME).error(msg)
                     raise ValueError(msg)
                 date_format_type_set.add(new_element[0])
@@ -244,23 +199,14 @@ class DateTimeModelElement(ModelElementInterface):
             raise ValueError(msg)
         self.date_format_parts = date_format_parts
 
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):  # skipcq: PYL-R0201
-        """
-        Get all possible child model elements of this element.
-        @return None as no children are allowed.
-        """
-        return None
-
     def get_match_element(self, path: str, match_context):
         """
         Try to find a match on given data for this model element and all its children.
-        When a match is found, the matchContext is updated accordingly.
-        @return None when there is no match, MatchElement otherwise. The matchObject returned is a tuple containing the datetime
-        object and the seconds since 1970
+        When a match is found, the match_context is updated accordingly.
+        @param path to be printed in the MatchElement.
+        @param match_context the match_context to be analyzed.
+        @return None when there is no match, MatchElement otherwise. The match_object returned is a tuple containing the datetime
+                object and the seconds since 1970.
         """
         parse_pos = 0
         # Year, month, day, hour, minute, second, fraction, gmt-seconds:
@@ -310,12 +256,12 @@ class DateTimeModelElement(ModelElementInterface):
             else:
                 try:
                     result[date_format_part[0]] = transform_function(next_data)
-                # skipcq: FLK-E722
-                except:
+                except ValueError:
                     # Parsing failed, most likely due to wrong format.
                     return None
 
         date_str = match_context.match_data[:parse_pos]
+        result[7] /= self.timestamp_scale
 
         # Now combine the values and build the final value.
         parsed_date_time = None
@@ -336,10 +282,8 @@ class DateTimeModelElement(ModelElementInterface):
                         result[1] = current_date.month
                     if result[2] == 0:
                         result[2] = current_date.day
-                parsed_date_time = datetime(result[0], result[1], result[2], result[3], result[4], result[5], microseconds,
-                                            self.time_zone)
-            # skipcq: FLK-E722
-            except:
+                parsed_date_time = datetime(result[0], result[1], result[2], result[3], result[4], result[5], microseconds, self.time_zone)
+            except ValueError:
                 # The values did not form a valid datetime object, e.g. when the day of month is out of range. The rare case where dates
                 # without year are parsed and the last parsed timestamp was from the previous non-leap year but the current timestamp is it,
                 # is ignored. Values that sparse and without a year number are very likely to result in invalid data anyway.
@@ -373,9 +317,9 @@ class DateTimeModelElement(ModelElementInterface):
                             parsed_date_time = next_year_date_time
                             total_seconds = next_year_total_seconds
                             self.last_parsed_seconds = total_seconds
-                            msg = "DateTimeModelElement unqualified timestamp year wraparound detected from %s to %s" % (
-                                datetime.fromtimestamp(self.last_parsed_seconds, self.time_zone).isoformat(),
-                                parsed_date_time.isoformat())
+                            msg = f"DateTimeModelElement unqualified timestamp year wraparound detected from " \
+                                  f"{datetime.fromtimestamp(self.last_parsed_seconds, self.time_zone).isoformat()} to " \
+                                  f"{parsed_date_time.isoformat()}"
                             logging.getLogger(DEBUG_LOG_NAME).warning(msg)
                             print("WARNING: " + msg, file=sys.stderr)
                         else:
@@ -391,8 +335,8 @@ class DateTimeModelElement(ModelElementInterface):
                                 self.last_parsed_seconds = total_seconds
                             else:
                                 # None of both seems correct, just report that.
-                                msg = "DateTimeModelElement time inconsistencies parsing %s, expecting value around %d. " \
-                                      "Check your settings!" % (repr(date_str), self.last_parsed_seconds)
+                                msg = f"DateTimeModelElement time inconsistencies parsing {repr(date_str)}, expecting value around " \
+                                      f"{self.last_parsed_seconds}. Check your settings!"
                                 logging.getLogger(DEBUG_LOG_NAME).warning(msg)
                                 print("WARNING: " + msg, file=sys.stderr)
 
@@ -408,7 +352,7 @@ class DateTimeModelElement(ModelElementInterface):
                 parse_pos += 1
                 resulting_key = None
                 # only if the next character is in A-Z, a valid resulting_key can exist.
-                if match_context.match_data[parse_pos] in search_tz_dict.keys():
+                if match_context.match_data[parse_pos] in search_tz_dict:
                     # search the first fitting resulting_key in the sorted tz_dict and break the loop.
                     for key in search_tz_dict[match_context.match_data[parse_pos]]:
                         if match_context.match_data[parse_pos:].startswith(key):
@@ -466,7 +410,7 @@ class DateTimeModelElement(ModelElementInterface):
                 # the offset must be subtracted, because the timestamp should always be UTC.
                 total_seconds -= tz_specifier_offset
         match_context.update(date_str)
-        return MatchElement("%s/%s" % (path, self.element_id), date_str, total_seconds, None)
+        return MatchElement(f"{path}/{self.element_id}", date_str, total_seconds, None)
 
     @staticmethod
     def parse_fraction(value_str: bytes):
@@ -479,9 +423,9 @@ class MultiLocaleDateTimeModelElement(ModelElementInterface):
     This class defines a model element to parse date or datetime values from log sources.
     The date or datetime can contain timestamps encoded in different locales or on machines, where host/service locale does not match data
     locale(s).
-    CAVEAT: Unlike other model elements, this element is not completely stateless! As parsing of semiqualified date values without any
+    CAVEAT: Unlike other model elements, this element is not completely stateless! As parsing of semi qualified date values without any
     year information may produce wrong results, e.g. wrong year or 1 day off due to incorrect leap year handling, this object
-    will keep track of the most recent timestamp parsed and will use it to regain information about the year in semiqualified
+    will keep track of the most recent timestamp parsed and will use it to regain information about the year in semi qualified
     date values. Still this element will not complain when parsed timestamp values are not strictly sorted, this should be done
     by filtering modules later on. The sorting requirements here are only, that each new timestamp value may not be more than
     2 days before and 1 month after the most recent one observer.
@@ -496,46 +440,29 @@ class MultiLocaleDateTimeModelElement(ModelElementInterface):
     def __init__(self, element_id: str, date_formats: list, start_year: int = None, max_time_jump_seconds: int = 86400):
         """
         Create a new MultiLocaleDateTimeModelElement object.
+        @param element_id an identifier for the ModelElement which is shown in the path.
         @param date_formats this parameter is a list of tuples, each tuple containing information about one date format to support.
-        The tuple structure is (format_string, format_timezone, format_locale). The format_string may contain the same elements as supported
-        by strptime from datetime.datetime. The format_locale defines the locale for the string content, e.g. de_DE for german,
-        but also the data IO encoding, e.g. ISO-8859-1. The locale information has to be available, e.g. using "locale-gen" on
-        Debian systems. The format_timezone can be used to define the timezone of the timestamp parsed. When None, UTC is used.
-        The timezone support may only be sufficient for very simple usecases, e.g. all data from one source configured to create
-        timestamps in that timezone.
-        @param start_year when given, parsing will use this year value for semiqualified timestamps to add correct year information.
-        This is especially relevant for historic datasets as otherwise leap year handling may fail. The startYear parameter will
-        only take effect when the first timestamp to be parsed by this object is also semiqualified. Otherwise the year information
-        is extracted from this record. When empty and first parsing invocation involves a semiqualified date, the current year
-        in UTC timezone is used.
+               The tuple structure is (format_string, format_timezone, format_locale). The format_string may contain the same elements as
+               supported by strptime from datetime.datetime. The format_locale defines the locale for the string content, e.g. de_DE for
+               german, but also the data IO encoding, e.g. ISO-8859-1. The locale information has to be available, e.g. using "locale-gen"
+               on Debian systems. The format_timezone can be used to define the timezone of the timestamp parsed. When None, UTC is used.
+               The timezone support may only be sufficient for very simple use-cases, e.g. all data from one source configured to create
+               timestamps in that timezone.
+        @param start_year when given, parsing will use this year value for semi qualified timestamps to add correct year information.
+               This is especially relevant for historic datasets as otherwise leap year handling may fail. The startYear parameter will
+               only take effect when the first timestamp to be parsed by this object is also semi qualified. Otherwise, the year information
+               is extracted from this record. When empty and first parsing invocation involves a semi qualified date, the current year
+               in UTC timezone is used.
         @param max_time_jump_seconds for detection of year wraps with date formats missing year information, also the current time
-        of values has to be tracked. This value defines the window within that the time may jump between two matches. When not
-        within that window, the value is still parsed, corrected to the most likely value but does not change the detection year.
+               of values has to be tracked. This value defines the window within that the time may jump between two matches. When not
+               within that window, the value is still parsed, corrected to the most likely value but does not change the detection year.
         """
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
+        super().__init__(element_id, start_year=start_year, max_time_jump_seconds=max_time_jump_seconds)
         if len(date_formats) == 0:
             msg = "At least one date_format must be specified."
             logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise ValueError(msg)
 
-        if max_time_jump_seconds is not None and not isinstance(max_time_jump_seconds, int) or isinstance(max_time_jump_seconds, bool):
-            msg = "max_time_jump_seconds has to be of the type integer."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if max_time_jump_seconds <= 0:
-            msg = "max_time_jump_seconds must not be lower than 1 second."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.max_time_jump_seconds = max_time_jump_seconds
-
         format_has_year_flag = False
         default_locale = locale.getdefaultlocale()
         self.date_time_model_elements: List[DateTimeModelElement] = []
@@ -555,8 +482,8 @@ class MultiLocaleDateTimeModelElement(ModelElementInterface):
                 raise ValueError(msg)
             for date_time_model_element in self.date_time_model_elements:
                 if date_format.startswith(date_time_model_element.date_format):
-                    msg = "Invalid order of date_formats. %s starts with %s. More specific datetimes would be skipped." % (
-                        date_format.decode(), date_time_model_element.date_format.decode())
+                    msg = f"Invalid order of date_formats. {date_format.decode()} starts with " \
+                          f"{date_time_model_element.date_format.decode()}. More specific datetimes would be skipped."
                     logging.getLogger(DEBUG_LOG_NAME).error(msg)
                     raise ValueError(msg)
             self.date_time_model_elements.append(DateTimeModelElement(
@@ -571,35 +498,20 @@ class MultiLocaleDateTimeModelElement(ModelElementInterface):
         if locale.getlocale() != default_locale:
             locale.resetlocale()
 
-        if start_year is not None and not isinstance(start_year, int) or isinstance(start_year, bool):
-            msg = "start_year has to be of the type integer."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
         if (not format_has_year_flag) and (start_year is None):
             self.start_year = time.gmtime(None).tm_year
         elif start_year is None:   # this is needed so start_year is at any point an integer. (instead of being None)
             self.start_year = 0
-        else:
-            self.start_year = start_year
         self.last_parsed_seconds = 0
 
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):  # skipcq: PYL-R0201
-        """
-        Get all possible child model elements of this element.
-        @return empty list as there are no children of this element.
-        """
-        return None
-
     def get_match_element(self, path: str, match_context):
         """
         Check if the data to match within the content is suitable to be parsed by any of the supplied date formats.
+        @param path to be printed in the MatchElement.
+        @param match_context the match_context to be analyzed.
         @return On match return a match_object containing a tuple of the datetime object and the seconds since 1970. When not matching,
-        None is returned. When the timestamp data parsed would be far off from the last ones parsed, so that correction may
-        not be applied correctly, then the method will also return None.
+                None is returned. When the timestamp data parsed would be far off from the last ones parsed, so that correction may
+                not be applied correctly, then the method will also return None.
         """
         for i, date_time_model_element in enumerate(self.date_time_model_elements):
             locale.setlocale(locale.LC_ALL, date_time_model_element.text_locale)
