@@ -13,10 +13,9 @@ this program. If not, see <http://www.gnu.org/licenses/>.
 """
 
 import json
-import sys
 import warnings
 import logging
-from typing import List, Union
+from typing import List, Union, Any
 from json import JSONDecodeError
 from aminer.parsing.MatchElement import MatchElement
 from aminer.parsing.MatchContext import MatchContext
@@ -44,91 +43,52 @@ def format_float(val):
         if "." in val:
             pos_point = val.find(".")
         if len(val) - val.find(sign) <= 2:
-            result = format(float(val), "1.%dE" % (val.find(exp) - pos_point))[:-2]
-            result += format(float(val), "1.%dE" % (val.find(exp) - pos_point))[-1]
+            result = format(float(val), f"1.{val.find(exp) - pos_point}E")[:-2]
+            result += format(float(val), f"1.{val.find(exp) - pos_point}E")[-1]
             return result
-        return format(float(val), "1.%dE" % (val.find(exp) - pos_point))
+        return format(float(val), f"1.{val.find(exp) - pos_point}E")
     return float(val)
 
 
 class JsonModelElement(ModelElementInterface):
     """Parse single- or multi-lined JSON data."""
 
-    def __init__(self, element_id: str, key_parser_dict: dict, optional_key_prefix: str = "optional_key_", allow_all_fields: bool = False):
+    def __init__(self, element_id: str, key_parser_dict: dict, optional_key_prefix: str = "optional_key_", nullable_key_prefix: str = "+",
+                 allow_all_fields: bool = False):
         """
         Initialize the JsonModelElement.
         @param element_id: The ID of the element.
         @param key_parser_dict: A dictionary of all keys with the according parsers. If a key should be optional, the associated parser must
-            start with the OptionalMatchModelElement. To allow every key in a JSON object use "key": "ALLOW_ALL". To allow only empty arrays
-            - [] - use "key": "EMPTY_ARRAY". To allow only empty objects - {} - use "key": "EMPTY_OBJECT".
-            To allow only empty strings - "" - use "key": "EMPTY_STRING". To allow all keys in an object for a parser use "ALLOW_ALL_KEYS":
-            parser.
+               start with the OptionalMatchModelElement. To allow every key in a JSON object use "key": "ALLOW_ALL". To allow only empty
+               arrays - [] - use "key": "EMPTY_ARRAY". To allow only empty objects - {} - use "key": "EMPTY_OBJECT".
+               To allow only empty strings - "" - use "key": "EMPTY_STRING". To allow all keys in an object for a parser use
+               "ALLOW_ALL_KEYS": parser. To allow only null values use "key": "NULL_OBJECT".
         @param optional_key_prefix: If some key starts with the optional_key_prefix it will be considered optional.
+        @param nullable_key_prefix: The value of this key may be null instead of any expected value.
         @param allow_all_fields: Unknown fields are skipped without parsing with any parsing model.
         """
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-
-        if not isinstance(key_parser_dict, dict):
-            msg = "key_parser_dict has to be of the type dict."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        self.children: List[dict] = []
-        self.find_children_in_dict(key_parser_dict, self.children)
-        self.key_parser_dict = key_parser_dict
-
-        if not isinstance(optional_key_prefix, str):
-            msg = "optional_key_prefix has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(optional_key_prefix) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.optional_key_prefix = optional_key_prefix
-        if not isinstance(allow_all_fields, bool):
-            msg = "allow_all_fields has to be of the type bool."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        self.allow_all_fields = allow_all_fields
+        super().__init__(element_id, key_parser_dict=key_parser_dict, optional_key_prefix=optional_key_prefix,
+                         nullable_key_prefix=nullable_key_prefix, allow_all_fields=allow_all_fields)
         self.dec_escapes = False
+        self.validate_key_parser_dict(key_parser_dict)
 
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):
-        """Return all model elements of the sequence."""
-        return self.children
-
-    def find_children_in_dict(self, dictionary: dict, children: list):
-        """Find all children and append them to the children list."""
+    def validate_key_parser_dict(self, dictionary: dict):
+        """Validate the key_parser_dict."""
         for value in dictionary.values():
             if isinstance(value, ModelElementInterface):
-                children.append(value)
-            elif isinstance(value, list):
+                continue
+            if isinstance(value, list):
                 if len(value) == 0:
                     msg = "lists in key_parser_dict must have at least one entry."
                     logging.getLogger(DEBUG_LOG_NAME).error(msg)
                     raise ValueError(msg)
 
-                value_list: List[dict] = []
                 for v in value:
                     if isinstance(v, dict):
-                        self.find_children_in_dict(v, value_list)
-                    else:
-                        value_list.append(v)
-                children.append(value_list)
+                        self.validate_key_parser_dict(v)
             elif isinstance(value, dict):
-                self.find_children_in_dict(value, children)
-            elif value not in ("ALLOW_ALL", "EMPTY_ARRAY", "EMPTY_OBJECT", "EMPTY_STRING", "ALLOW_ALL_KEYS"):
+                self.validate_key_parser_dict(value)
+            elif value not in ("ALLOW_ALL", "EMPTY_ARRAY", "EMPTY_OBJECT", "EMPTY_STRING", "ALLOW_ALL_KEYS", "NULL_OBJECT"):
                 msg = "wrong type found in key_parser_dict."
                 logging.getLogger(DEBUG_LOG_NAME).error(msg)
                 raise TypeError(msg)
@@ -139,24 +99,52 @@ class JsonModelElement(ModelElementInterface):
             return True
         return False
 
+    def get_full_key(self, key, dictionary):
+        """Find the full key in the dictionary."""
+        options = [self.optional_key_prefix + self.nullable_key_prefix + key, self.nullable_key_prefix + self.optional_key_prefix + key,
+                   self.optional_key_prefix + key, self.nullable_key_prefix + key]
+        for option in options:
+            if option in dictionary:
+                return option
+        return key
+
+    def get_stripped_key(self, key):
+        """Return the key without optional_key_prefix and nullable_key_prefix."""
+        if key.startswith(self.optional_key_prefix):
+            key = key[len(self.optional_key_prefix):]
+        if key.startswith(self.nullable_key_prefix):
+            key = key[len(self.nullable_key_prefix):]
+        if key.startswith(self.optional_key_prefix):
+            key = key[len(self.optional_key_prefix):]
+        return key
+
+    def is_nullable_key(self, key):
+        """Check if the key is nullable."""
+        return key.startswith(self.nullable_key_prefix) or (
+                key.startswith(self.optional_key_prefix) and key[len(self.optional_key_prefix):].startswith(self.nullable_key_prefix))
+
     def get_match_element(self, path: str, match_context):
         """
-        Try to parse all of the match_context against JSON.
+        Try to parse all the match_context against JSON.
         When a match is found, the match_context is updated accordingly.
         @param path the model path to the parent model element invoking this method.
         @param match_context an instance of MatchContext class holding the data context to match against.
         @return the matchElement or None if model did not match.
         """
-        current_path = "%s/%s" % (path, self.element_id)
+        current_path = f"{path}/{self.element_id}"
         old_match_data = match_context.match_data
         matches: Union[List[Union[MatchElement, None]]] = []
         try:
             index = 0
+            # There can be a valid case in which the text contains for example \x2d, \\x2d or \\\\x2d, which basically should be decoded
+            # into the unicode form.
             while index != -1:
-                index = match_context.match_data.find(rb"\x", index)
-                if index != -1 and index != match_context.match_data.find(b"\\x", index-1):
-                    match_context.match_data = match_context.match_data.decode("unicode-escape").encode()
-                    break
+                index = match_context.match_data.find(rb"\x")
+                if index != -1:
+                    try:
+                        match_context.match_data = match_context.match_data.decode("unicode-escape").encode()
+                    except UnicodeDecodeError:
+                        break
             index = 0
             while index != -1:
                 index = match_context.match_data.find(b"\\", index)
@@ -202,8 +190,7 @@ class JsonModelElement(ModelElementInterface):
 
         for i, key in enumerate(json_match_data.keys()):
             split_key = key
-            if self.optional_key_prefix + key in json_dict:
-                key = self.optional_key_prefix + key
+            key = self.get_full_key(key, json_dict)
             if key not in json_dict:
                 index = match_context.match_data.find(key.encode())
                 match_context.update(match_context.match_data[:index])
@@ -225,7 +212,16 @@ class JsonModelElement(ModelElementInterface):
                 logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + "RETURN [NONE] 3, Key: " + split_key + ", Value: " + repr(value))
                 return [None]
             if isinstance(value, dict):
-                matches += self.parse_json_dict(value, json_match_data[split_key], "%s/%s" % (current_path, split_key), match_context)
+                if json_match_data[split_key] is None and (self.is_nullable_key(key) or json_dict[key] == "NULL_OBJECT"):
+                    data = b"null"
+                    matches.append(MatchElement(current_path, data, data, None))
+                    index = match_context.match_data.find(data)
+                    if match_context.match_data[index + 4] == 34:  # "
+                        index += 1
+                    match_context.update(match_context.match_data[:index + len(data)])
+                    return matches
+
+                matches += self.parse_json_dict(value, json_match_data[split_key], f"{current_path}/{split_key}", match_context)
                 if json_match_data[split_key] == {}:
                     index = match_context.match_data.find(split_key.encode())
                     index = match_context.match_data.find(b"}", index)
@@ -265,48 +261,48 @@ class JsonModelElement(ModelElementInterface):
                     matches.append(None)
             else:
                 if key != split_key and split_key not in json_match_data:
-                    logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + "Optional Key %s not found in json_match_data" % key)
+                    logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + f"Optional Key {key} not found in json_match_data")
                     continue
                 if split_key not in json_match_data:
                     logging.getLogger(DEBUG_LOG_NAME).debug(
-                        debug_log_prefix + "Key %s not found in json_match_data. RETURN [NONE] 4" % split_key)
+                        debug_log_prefix + f"Key {split_key} not found in json_match_data. RETURN [NONE] 4")
                     return [None]
-                match_element, index, data = self.parse_json_object(
-                    json_dict, json_match_data, key, split_key, current_path, match_context)
-                if match_element is not None or (match_element is None and not key.startswith(self.optional_key_prefix)):
-                    matches.append(match_element)
-                    if index == -1 and match_element is None:
-                        logging.getLogger(DEBUG_LOG_NAME).debug(
-                            debug_log_prefix + "Necessary element did not match! Key: %s, MatchElement: %s, Data: %s, IsFloat %s, "
-                                               "Index: %d, MatchContext: %s" % (
-                                                    key, match_element, data.decode(), isinstance(json_match_data[split_key], float), index,
-                                                    match_context.match_data.replace(b"\\", b"").decode()))
-                        return matches
+                match_element, index, data = self.parse_json_object(json_dict, json_match_data, key, split_key, current_path, match_context)
+                matches.append(match_element)
+                if index == -1 and match_element is None:
+                    backslash = b"\\"
+                    logging.getLogger(DEBUG_LOG_NAME).debug(
+                        debug_log_prefix + f"Necessary element did not match! Key: {key}, MatchElement: {match_element}, Data: "
+                                           f"{data.decode()}, IsFloat {isinstance(json_match_data[split_key], float)}, Index: {index}, "
+                                           f"MatchContext: {match_context.match_data.replace(backslash, b'').decode()}")
+                    return matches
                 match_context.update(match_context.match_data[:index + len(data)])
-        missing_keys = [x for x in json_dict if x not in json_match_data and x != "ALLOW_ALL_KEYS"]
+        missing_keys = [x for x in json_dict if self.get_stripped_key(x) not in json_match_data and x != "ALLOW_ALL_KEYS" and
+                        not (x.startswith(self.optional_key_prefix) or x.startswith(self.nullable_key_prefix + self.optional_key_prefix))]
         for key in missing_keys:
-            if not key.startswith(self.optional_key_prefix):
-                logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + "Missing Key: " + key)
-                return [None]
+            logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + "Missing Key: " + key)
+            return [None]
         return matches
 
     def check_keys(self, json_dict, json_match_data, match_context):
         """Check if no keys are missing and if the value types match."""
         if "ALLOW_ALL_KEYS" in json_dict.keys():
             return True
-        missing_keys = [x for x in json_dict if x not in json_match_data]
+        if json_match_data is None:
+            return False
+        missing_keys = [x for x in json_dict if self.get_stripped_key(x) not in json_match_data and not (x.startswith(
+            self.optional_key_prefix) or x.startswith(self.nullable_key_prefix + self.optional_key_prefix))]
         for key in missing_keys:
-            if not key.startswith(self.optional_key_prefix):
+            if (not key.startswith(self.nullable_key_prefix) or (
+                    key.startswith(self.nullable_key_prefix) and key[len(self.nullable_key_prefix):] not in json_match_data)):
                 index = match_context.match_data.find(key.encode())
                 match_context.update(match_context.match_data[:index])
                 logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + "RETURN [NONE] 1. Key: " + key)
                 return False
         for key in json_dict.keys():
-            k = key
-            if key.startswith(self.optional_key_prefix):
-                k = key.replace(self.optional_key_prefix, "")
-            if k in json_match_data and isinstance(json_match_data[k], list) and not isinstance(json_dict[key], list) and json_dict[
-                    key] != "EMPTY_ARRAY":
+            k = self.get_stripped_key(key)
+            if not isinstance(json_match_data, dict) or (k in json_match_data and isinstance(json_match_data[k], list) and not isinstance(
+                    json_dict[key], list) and json_dict[key] != "EMPTY_ARRAY"):
                 index = match_context.match_data.find(key.encode())
                 match_context.update(match_context.match_data[:index])
                 logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + "RETURN [NONE] 5. Key: " + key)
@@ -317,7 +313,7 @@ class JsonModelElement(ModelElementInterface):
         """Flatten a list of lists using this method recursively."""
         if not isinstance(lst, list):
             return None
-        res = []
+        res: List[Any] = []
         for val in lst:
             if isinstance(val, list):
                 res += self.flatten_list(val)
@@ -327,7 +323,9 @@ class JsonModelElement(ModelElementInterface):
 
     def parse_json_array(self, json_dict: dict, json_match_data: dict, key: str, split_key: str, current_path: str, matches: list,
                          match_context, i: int):
-        """Parse a array in a json object."""
+        """Parse an array in a json object."""
+        if self.is_nullable_key(key) and json_match_data[split_key] is None:
+            return None
         if not isinstance(json_match_data[split_key], list):
             if key.startswith(self.optional_key_prefix) and json_match_data[split_key] is None:
                 data = b"null"
@@ -356,7 +354,7 @@ class JsonModelElement(ModelElementInterface):
                     data = str(data).encode()
                 if isinstance(val, dict):  # skipcq: PYL-R1723
                     matches += self.parse_json_dict(
-                        val, match_array[j], "%s/%s" % (current_path, split_key), match_context)
+                        val, match_array[j], f"{current_path}/{split_key}", match_context)
                     if matches[-1] is None:
                         if len(value) - 1 == k:
                             logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + "No match found for key " + split_key)
@@ -398,12 +396,14 @@ class JsonModelElement(ModelElementInterface):
                     if match_element is not None or (match_element is None and not key.startswith(self.optional_key_prefix)):
                         matches.append(match_element)
                         if index == -1:
-                            if len(value) - 1 > k:
+                            if len(value) - 1 == k:
                                 return matches
                             del matches[-1]
                             continue
+                    if len(matches) == 0:
+                        return [None]
                     if matches[-1] is None:
-                        if len(value) - 1 > k:
+                        if len(value) - 1 == k:
                             logging.getLogger(DEBUG_LOG_NAME).debug(debug_log_prefix + "RETURN MATCHES 3")
                             return matches
                         del matches[-1]
@@ -429,6 +429,15 @@ class JsonModelElement(ModelElementInterface):
             data = str(data).replace("T", "t").replace("F", "f").encode()
         elif data is None:
             data = b"null"
+            if self.is_nullable_key(key) or json_dict[key] == "NULL_OBJECT":
+                start = 0
+                if "null" in key:
+                    start = match_context.match_data.find(data) + 4
+                index = match_context.match_data.find(data, start)
+                if match_context.match_data[index + 4] == 34:
+                    index += 1
+                return MatchElement(current_path, data, data, None), index, data
+            return None, -1, data
         elif not isinstance(data, bytes):
             data = str(data).encode()
         if json_dict[key] == "ALLOW_ALL":
@@ -451,8 +460,8 @@ class JsonModelElement(ModelElementInterface):
             if match_element is not None and len(match_element.match_string) != len(data) and (
                     not isinstance(match_element.match_object, bytes) or len(match_element.match_object) != len(data)):
                 logging.getLogger(DEBUG_LOG_NAME).debug(
-                    debug_log_prefix + "Data length not matching! match_string: %d, data: %d, data: %s" % (
-                        len(match_element.match_string), len(data), data.decode()))
+                    debug_log_prefix + f"Data length not matching! match_string: {len(match_element.match_string)}, data: {len(data)},"
+                                       f" data: {data.decode()}")
                 match_element = None
             index = max([match_context.match_data.replace(b"\\", b"").find(split_key.encode()),
                          match_context.match_data.find(split_key.encode()), match_context.match_data.decode().find(split_key)])
