@@ -11,8 +11,6 @@ FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
-import logging
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.parsing.MatchElement import MatchElement
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 
@@ -24,22 +22,13 @@ class OptionalMatchModelElement(ModelElementInterface):
     """
 
     def __init__(self, element_id: str, optional_element: ModelElementInterface):
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-
-        if not isinstance(optional_element, ModelElementInterface):
-            msg = "optional_element has to be of the type ModelElementInterface."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        self.optional_element = optional_element
-        self.empty_match_element = MatchElement("%s/%s" % ("None", self.element_id), b"", None, None)
+        """
+        Initialize the ModelElement.
+        @param element_id an identifier for the ModelElement which is shown in the path.
+        @param optional_element the element to be optionally matched.
+        """
+        super().__init__(element_id, optional_element=optional_element)
+        self.empty_match_element = MatchElement(f"None/{self.element_id}", b"", None, None)
 
     def get_id(self):
         """Get the element ID."""
@@ -51,7 +40,7 @@ class OptionalMatchModelElement(ModelElementInterface):
 
     def get_match_element(self, path: str, match_context):
         """@return the embedded child match or an empty match."""
-        current_path = "%s/%s" % (path, self.element_id)
+        current_path = f"{path}/{self.element_id}"
 
         start_data = match_context.match_data
         match = self.optional_element.get_match_element(current_path, match_context)
