@@ -11,9 +11,7 @@ FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
-import logging
 from typing import List
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.parsing.MatchElement import MatchElement
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 
@@ -22,34 +20,12 @@ class SequenceModelElement(ModelElementInterface):
     """This class defines an element to find matches that comprise matches of all given child model elements."""
 
     def __init__(self, element_id: str, children: List["ModelElementInterface"]):
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-
-        if not isinstance(children, list):
-            msg = "children has to be of the type list."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        for child in children:
-            if not isinstance(child, ModelElementInterface):
-                msg = "every child has to be of the type ModelElementInterface."
-                logging.getLogger(DEBUG_LOG_NAME).error(msg)
-                raise TypeError(msg)
-        self.children = children
-
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):
-        """Return all model elements of the sequence."""
-        return self.children
+        """
+        Initialize the ModelElement.
+        @param element_id an identifier for the ModelElement which is shown in the path.
+        @param children a list of child elements to be iterated through.
+        """
+        super().__init__(element_id, children=children)
 
     def get_match_element(self, path, match_context):
         """
@@ -59,7 +35,7 @@ class SequenceModelElement(ModelElementInterface):
         @param match_context an instance of MatchContext class holding the data context to match against.
         @return the matchElement or None if model did not match.
         """
-        current_path = "%s/%s" % (path, self.element_id)
+        current_path = f"{path}/{self.element_id}"
         start_data = match_context.match_data
         matches = []
         for child_element in self.children:
