@@ -11,8 +11,6 @@ FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
-import logging
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.parsing.MatchElement import MatchElement
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 
@@ -20,28 +18,6 @@ from aminer.parsing.ModelElementInterface import ModelElementInterface
 class WhiteSpaceLimitedDataModelElement(ModelElementInterface):
     """This class defines a model element that represents a variable amount of characters delimited by a white space."""
 
-    def __init__(self, element_id: str):
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):  # skipcq: PYL-R0201
-        """
-        Get all possible child model elements of this element.
-        @return None as there are no children of this element.
-        """
-        return None
-
     def get_match_element(self, path: str, match_context):
         """
         Find the maximum number of bytes before encountering whitespace or end of data.
@@ -58,4 +34,4 @@ class WhiteSpaceLimitedDataModelElement(ModelElementInterface):
             return None
         match_data = data[:match_len]
         match_context.update(match_data)
-        return MatchElement("%s/%s" % (path, self.element_id), match_data, match_data, None)
+        return MatchElement(f"{path}/{self.element_id}", match_data, match_data, None)
