@@ -18,25 +18,25 @@ from aminer.AminerConfig import DEBUG_LOG_NAME
 
 
 colflame = ("\033[31m"
-            "            *     (        )       (     \n"
-            "   (      (  `    )\\ )  ( /(       )\\ )  \n"
-            "   )\\     )\\))(  (()/(  )\\()) (   (()/(  \n"
+            "           *     (       )       (     \n"
+            "   (     (  `    )\\ ) ( /(       )\\ )  \n"
+            "   )\\    )\\))(  (()/( )\\()) (   (()/(  \n"
             "\033[33m"
-            "((((_)(  ((_)()\\  /(_))((_)\\  )\\   /(_)) \n"
-            " )\\ _ )\\ (_()((_)(_))   _((_)((_) (_))   \n"
-            " (_)\033[39m_\\\033[33m(_)\033[39m|  \\/  ||_ _| | \\| || __|| _ \\  \n"
-            "  / _ \\  | |\\/| | | |  | .` || _| |   /  \n"
-            " /_/ \\_\\ |_|  |_||___| |_|\\_||___||_|_\\  "
+            "((((_)( ((_)()\\  /(_))(_)\\  )\\   /(_)) \n"
+            " )\\ _ )\\(_()((_)(_))  _((_)((_) (_))   \n"
+            " (_)\033[39m_\\\033[33m()\033[39m|  \\/  ||_ _|| \\| || __|| _ \\  \n"
+            "  / _ \\ | |\\/| | | | | .` || _| |   /  \n"
+            " /_/ \\_\\|_|  |_||___||_|\\_||___||_|_\\  "
             "\033[39m")
 
-flame = ("            *     (        )       (     \n"
-         "   (      (  `    )\\ )  ( /(       )\\ )  \n"
-         "   )\\     )\\))(  (()/(  )\\()) (   (()/(  \n"
-         "((((_)(  ((_)()\\  /(_))((_)\\  )\\   /(_)) \n"
-         " )\\ _ )\\ (_()((_)(_))   _((_)((_) (_))   \n"
-         " (_)_\\(_)|  \\/  ||_ _| | \\| || __|| _ \\  \n"
-         "  / _ \\  | |\\/| | | |  | .` || _| |   /  \n"
-         " /_/ \\_\\ |_|  |_||___| |_|\\_||___||_|_\\  ")
+flame = ("           *     (       )       (     \n"
+         "   (     (  `    )\\ ) ( /(       )\\ )  \n"
+         "   )\\    )\\))(  (()/( )\\()) (   (()/(  \n"
+         "((((_)( ((_)()\\  /(_))(_)\\  )\\   /(_)) \n"
+         " )\\ _ )\\(_()((_)(_))  _((_)((_) (_))   \n"
+         " (_)_\\()|  \\/  ||_ _|| \\| || __|| _ \\  \n"
+         "  / _ \\ | |\\/| | | | | .` || _| |   /  \n"
+         " /_/ \\_\\|_|  |_||___||_|\\_||___||_|_\\  ")
 
 
 def supports_color():
